#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : asr
# @Time         : 2023/11/21 13:57
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *


import whisper
from datetime import timedelta

def transcribe_audio(audio_path, model='base', language='zh'):
    model = whisper.load_model(model, download_root="/Users/betterme/PycharmProjects/AI/pyvideotrans/models")  # Change this to your desired model
    print(f"Whisper model loaded.{language},{audio_path=}")
    transcribe = model.transcribe(audio_path, language=language)
    segments = transcribe['segments']
    print(f"{segments=}")
    result = ""
    for segment in segments:
        print(segment)
        startTime = str(0) + str(timedelta(seconds=int(segment['start']))) + ',000'
        endTime = str(0) + str(timedelta(seconds=int(segment['end']))) + ',000'
        text = segment['text']
        segmentId = segment['id'] + 1
        result += f"{segmentId}\n{startTime} --> {endTime}\n{text.strip()}\n\n"
    return result


if __name__ == '__main__':
    audio_path = "../../../zh_.wav"
    print(transcribe_audio(audio_path=audio_path))


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : chat_videos
# @Time         : 2025/3/20 10:19
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 


from meutils.pipe import *
from meutils.llm.clients import AsyncOpenAI
from meutils.apis.chatglm import glm_video_api  # VideoRequest, create_task, get_task
from meutils.str_utils.regular_expression import parse_url

from meutils.schemas.openai_types import chat_completion, chat_completion_chunk, CompletionRequest, CompletionUsage


class Completions(object):

    def __init__(self,
                 base_url: Optional[str] = None,
                 api_key: Optional[str] = None
                 ):
        self.client = AsyncOpenAI(
            base_url=base_url,
            api_key=api_key,
        )

    async def create(self, request: CompletionRequest):

        image_url = None
        prompt = request.last_user_content
        if urls := parse_url(prompt):
            image_url = urls[0]
            prompt = prompt.replace(image_url, "")

        # 创建任务
        video_request = glm_video_api.VideoRequest(image_url=image_url, prompt=prompt)
        response = await glm_video_api.create_task(video_request)
        taskid = response.id
        system_fingerprint = response.system_fingerprint

        # 获取任务
        for i in f"""> VideoTask(id={taskid.split('-')[-1]}, image_url={image_url}, prompt={prompt})\n""":
            await asyncio.sleep(0.03)
            yield i

        yield f"[🤫 任务进度]("
        for i in range(60):
            await asyncio.sleep(3)
            response = await glm_video_api.get_task(taskid, system_fingerprint)



            logger.debug(response)
            if response.task_status == "SUCCESS" or response.video_result:
                yield ")🎉🎉🎉\n\n"
                for video in response.video_result or []:
                    yield f"[^1]: [封面]({video.cover_image_url})\n\n"
                    yield f"[^2]: [视频]({video.url})\n\n"

                    yield f"[视频]({video.url})[^1][^2]\n\n"
                    yield f"![视频]({video.url})[^1][^2]\n\n"

                break
            else:
                yield "🔥"


if __name__ == '__main__':
    url = "https://oss.ffire.cc/files/lipsync.mp3"
    url = "https://lmdbk.com/5.mp4"
    content = [
        {"type": "text", "text": "总结下"},
        # {"type": "image_url", "image_url": {"url": url}},

        {"type": "video_url", "video_url": {"url": url}}

    ]
    request = CompletionRequest(
        # model="qwen-turbo-2024-11-01",
        model="gemini-all",
        # model="qwen-plus-latest",

        messages=[
            {
                'role': 'user',

                'content': content
            },

        ],
        stream=False,
    )
    arun(Completions().create(request))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : images_nx
# @Time         : 2026/2/13 11:16
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
from meutils.schemas.image_types import ImageRequest, ImagesResponse
from meutils.apis.volcengine_apis.utils import upload

from openai import AsyncClient

BASE_URL = "https://ml-platform-api.console.volcengine.com/ark/bff/api/cn-beijing/2024"


async def generate(request: ImageRequest, api_key: Optional[str] = None):
    default_headers = {
        "x-csrf-token": api_key.split("csrfToken=")[1].split(';')[0],
        "Cookie": api_key
    }
    client = AsyncClient(base_url=BASE_URL, default_headers=default_headers)

    payload = {
        "From": "pc",
        "Model": "doubao-seedream-5-0",
        "EndpointId": "doubao-seedream-5-0-260128",
        "Type": "normal",
        # "Images": [
        #     {
        #         "BucketName": "ark-seedream-4",
        #         "ObjectKey": "ark-seedream-4",
        #         "Url": "https://lf3-static.bytednsdoc.com/obj/eden-cn/LM-STH-hahK/ljhwZthlaukjlkulzlp/ark/seedream/seedream-4-5-03-in-01.png"
        #     },
        #     {
        #         "BucketName": "ark-seedream-4",
        #         "ObjectKey": "ark-seedream-4",
        #         "Url": "https://lf3-static.bytednsdoc.com/obj/eden-cn/LM-STH-hahK/ljhwZthlaukjlkulzlp/ark/seedream/seedream-4-5-03-in-02.png"
        #     },
        #     {
        #         "BucketName": "ark-seedream-4",
        #         "ObjectKey": "ark-seedream-4",
        #         "Url": "https://lf3-static.bytednsdoc.com/obj/eden-cn/LM-STH-hahK/ljhwZthlaukjlkulzlp/ark/seedream/seedream-4-5-03-in-03.png"
        #     }
        # ],
        "Prompt": request.prompt,
        "Ratio": "adaptive",
        "Size": "2048x2048",
        "ImageCount": request.n,
        "Seed": -1,

        "Stream": False,
        "Watermark": False
    }
    if request.resolution or request.size:
        payload["Size"] = request.resolution or request.size


    if request.aspect_ratio:
        payload["Ratio"] = request.aspect_ratio

    if request.image_urls:
        payload["Images"] = await upload(request.image_urls, api_key)

    logger.debug(bjson(payload))
    response = await client.post("/CreateImageGeneration", body=payload, cast_to=object, stream=True)
    logger.debug(bjson(response))

    data = []
    async for chunk in response:
        logger.debug(chunk)
        if items := chunk.get("items", []):
            data += [{"url": item.get("Url") for item in items}]

    return ImagesResponse(data=data)


if __name__ == '__main__':
    api_key = """ve_doc_history=82379%2C6269%2C6256%2C85128%2C86081%2C6348%2C85621%2C6260;_qimei_fingerprint=dd38b822c43601e30b795b0bb06bc28b;hasUserBehavior=1;monitor_huoshan_web_id=7467761534115284489;referrer_title=%E5%88%9B%E5%BB%BA%E8%A7%86%E9%A2%91%E7%94%9F%E6%88%90%E4%BB%BB%E5%8A%A1%20API--%E7%81%AB%E5%B1%B1%E6%96%B9%E8%88%9F%E5%A4%A7%E6%A8%A1%E5%9E%8B%E6%9C%8D%E5%8A%A1%E5%B9%B3%E5%8F%B0-%E7%81%AB%E5%B1%B1%E5%BC%95%E6%93%8E;AccountID=2109091919;user_locale=zh;signin_i18next=zh;monitor_session_id_flag=1;monitor_traceid_base_cookie=1419;volcengineLoginMethod=pwd;_tea_utm_cache_3569={%22utm_source%22:%22coopensrc%22%2C%22utm_medium%22:%22github%22%2C%22utm_campaign%22:%22doubao%22%2C%22utm_term%22:%22project%22%2C%22utm_content%22:%22aidrawio%22};volcfe-uuid=0701f6f2-a611-4599-a2fc-57cb015ff828;userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjEwOTA5MTkxOSwiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczNDk5Mzk0LCJpIjoiMjk2OTc3MmEwODIxMTFmMTlhZjEzNDM2YWMxMjAwM2YiLCJpZF9uIjoiMDQzNeaJi-acuueUqOaItyN5SFNrTXQiLCJtc2ciOm51bGwsInBpZCI6ImNkNDlmYTg3LWI3NzUtNDQwNS1iOTkzLTVmOTA0NTMyNDg5MSIsInNzX24iOiIwNDM15omL5py655So5oi3I3lIU2tNdCIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.cdpiB9xgcokJBJzG-S_BIdllMusycBqNLL8VNEnmlFI5i0fYstJUbAvLC-nbouHZjLhX9XzT45RjIqbFa-f1dnQHE6SmMf_CCPuxoZOpd7UnJTbCqQiKO_KRkdshxpuIxx7mV74ziS3UQWcNARIH663BxmsMsPWFx7Tntx3QOCdu_zljgJkjbxJZhcBhGOqGC2CMZXocr0MorPpcEVtXPOsRi9ulCBMSSH4kI5z4iigbliLyoYcsD3vNCmGO_vTOPDAdyEwGE395FwAnlB62JGnwVAreHvdPLE3YFMBII2JdDT03TGOrb1VFP6tLj2xOAWCDlVJnxRkW2fDZ16d71Q;__tea_cache_tokens_3569={%22web_id%22:%227467761534115284489%22%2C%22user_unique_id%22:%227467761534115284489%22%2C%22timestamp%22:1770907429996%2C%22_type_%22:%22default%22};volc-design-locale=zh;_qimei_h38=94cee221b20e31b701a412450300000ce19c18;finance-hub-sdk-lang=zh;p_c_check=1;volc_platform_clear_user_locale=1;__spti=11_000JnXNrWATPtPrMwlQ3ilQxfn2UtC;__sptiho=0B11_000JnXNrWATPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC;_qimei_i_1=5eea2c8b9109058ec395ff62598426e3f6bca3f1130a0783b68b2d582593206c616364c03980b1ddde92f7cc;_qimei_i_3=57ca79d3970c52d9c497aa625d8027e5a6bcf0f71a5b04d4e0872b502092276d32633f973989e28184b1;_qimei_uuid42=19c180a1723100cab20e31b701a4124555c551b916;_tea_utm_cache_520918={%22utm_source%22:%22coopensrc%22%2C%22utm_medium%22:%22github%22%2C%22utm_campaign%22:%22doubao%22%2C%22utm_term%22:%22project%22%2C%22utm_content%22:%22aidrawio%22};csrfToken=499beb4542dac5d353afbb1fffd981eb;digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzEwODAxOTQsImlhdCI6MTc3MDkwNzM5NCwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiJjZDQ5ZmE4Ny1iNzc1LTQ0MDUtYjk5My01ZjkwNDUzMjQ4OTEiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTd05MQTB0RFMwbFBoNWR2c1pOb1dtYzl2UHNBbjVjN0U3SmlmbmwrYVZDSngvY09NdHU1UzRnWW14NmJQTzdtZHpkajJmc3VKWngzYmxTby9nYk44U0piQTVXbXpKK2JtNStYbGV1SlFCQWdBQS8vOTdrMG13Y1FBQUFBPT0iLCJuYW1lIjoiMDQzNeaJi-acuueUqOaItyN5SFNrTXQiLCJzdWIiOiIyMTA5MDkxOTE5IiwidG9waWMiOiJzaWduaW5fY3JlZGVudGlhbCIsInRybiI6InRybjppYW06OjIxMDkwOTE5MTk6cm9vdCIsInZlcnNpb24iOiJ2MSIsInppcCI6Imd6aXAifQ.fw4LobnAByUwIaCOWhOOvF5igRzIo_l5lBme2SmfeT5vwky01EI2iBDBayuv_O39Uvl-MzS5Gmg2-tXFN7tqEyH2ERa1ymuZETFkFu3P-su9Uqb1VZnFpkaZsjHzhCTWIxvwDLmBCZM0aLN_LOBjhDyoRjd6agYr8XLrTM3UzVRb-MUg_yYBBSttvUpZdM4pLQ3magTu0xJQY0OfLg4IBTezfg84XsQJkh0wGaJI1N-_aXTTXTFBOBahMS8fKJrNG-mgV52xMxBqS_pt3piGwn3ssMVeD5JD5K474FMKxIhgwJUkdePfsVACAjBhaLmV6AmYX4UXo7lTmjHHIZnp3Q;gfkadpd=520918,36088|3569,42874;i18next=zh;isIntranet=0;login_scene=11;monitor_session_id=0008375069127979375;monitor_tracing_cookie=[];monitor_utm=%257B%2522utm_campaign%2522%253A%2522doubao%2522%252C%2522utm_content%2522%253A%2522aidrawio%2522%252C%2522utm_medium%2522%253A%2522github%2522%252C%2522utm_source%2522%253A%2522coopensrc%2522%252C%2522utm_term%2522%253A%2522project%2522%257D;s_v_web_id=verify_mjjfj194_6wx9uxHT_RbvK_42dT_BQQF_Am4VHcR3e6qJ;top_region=;vcloudWebId=0d8e34f9-2a27-4f3b-a86a-10cb562dbf67;VOLCFE_im_uuid=1770641165069598896"""

    api_key = """vcloudWebId=628549cd-c3d3-4cb8-936e-1539cee70c5a; monitor_huoshan_web_id=1935614982602037754; monitor_session_id_flag=1; connect.sid=s%3Af8e672eb-e208-489f-8e0c-9a777c81136a.ARdtNAOSZ0LqN1l%2FJ7UvQy7QqPiMkqiVDF2OK2Ug2CE; connect.sid=s%3Af8e672eb-e208-489f-8e0c-9a777c81136a.ARdtNAOSZ0LqN1l%2FJ7UvQy7QqPiMkqiVDF2OK2Ug2CE; i18next=zh; volc-design-locale=zh; volc_platform_clear_user_locale=1; p_c_check=1; user_locale=zh; monitor_session_id=9612063839874964093; isIntranet=0; VOLCFE_im_uuid=1770961291284332747; monitor_traceid_base_cookie=2; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzExMzQxMTUsImlhdCI6MTc3MDk2MTMxNSwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiIwMzFjZWY1OC04N2IzLTQ3NTQtOTlkNi1lNDA4NDUzMWEwNmMiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTd05MQTB0RFMwbEdqN3ZPc01tOEppRUNua3o4WHVtSnljWDVwWEluRCt3WTIzN0ZMaUJpYkdwczg2dTUvTjJmVjh5b3BuSGR1Vkt6MkNzMzFMbE1EbWFMRWw1K2ZtNXVkNTRWSUdDQUFBLy8vY0JpcE1jUUFBQUE9PSIsIm5hbWUiOiIwNDM15omL5py655So5oi3I3lIU2tNdCIsInN1YiI6IjIxMDkwOTE5MTkiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjEwOTA5MTkxOTpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.xLvOC-sKCi_a-wQuc-CkkN4D26G4Nf-R6O2oGPwYrUOSvyoxP-j_0Ms7qzKAGYE-_kHHnlk-DGji69INIAKsTUvJaesiCoreKJ-ObJfKp16eLiRCKZYceYnWgDHJBo9GdlNAYTuPj8GEb1pf1YAL-wBCFe4zrhrspQL0cV7UbAV0qEQBmpzN1I98I07a7tCT0zovJTq6WWHVjxborHEaN6LPB12vBJUjQOdtyYkOehBFSFI-JR-w-cidA-UFHhX3RyZeMxqFeF22XqlORzUp3uSbMwYPyf2-dQMAz1wC8E5Rt3-ymmHGgeeMEambLzVjlunruXuQD8IYLsaRcnT68w; digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzExMzQxMTUsImlhdCI6MTc3MDk2MTMxNSwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiIwMzFjZWY1OC04N2IzLTQ3NTQtOTlkNi1lNDA4NDUzMWEwNmMiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTd05MQTB0RFMwbEdqN3ZPc01tOEppRUNua3o4WHVtSnljWDVwWEluRCt3WTIzN0ZMaUJpYkdwczg2dTUvTjJmVjh5b3BuSGR1Vkt6MkNzMzFMbE1EbWFMRWw1K2ZtNXVkNTRWSUdDQUFBLy8vY0JpcE1jUUFBQUE9PSIsIm5hbWUiOiIwNDM15omL5py655So5oi3I3lIU2tNdCIsInN1YiI6IjIxMDkwOTE5MTkiLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjEwOTA5MTkxOTpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.xLvOC-sKCi_a-wQuc-CkkN4D26G4Nf-R6O2oGPwYrUOSvyoxP-j_0Ms7qzKAGYE-_kHHnlk-DGji69INIAKsTUvJaesiCoreKJ-ObJfKp16eLiRCKZYceYnWgDHJBo9GdlNAYTuPj8GEb1pf1YAL-wBCFe4zrhrspQL0cV7UbAV0qEQBmpzN1I98I07a7tCT0zovJTq6WWHVjxborHEaN6LPB12vBJUjQOdtyYkOehBFSFI-JR-w-cidA-UFHhX3RyZeMxqFeF22XqlORzUp3uSbMwYPyf2-dQMAz1wC8E5Rt3-ymmHGgeeMEambLzVjlunruXuQD8IYLsaRcnT68w; AccountID=2109091919; AccountID=2109091919; userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjEwOTA5MTkxOSwiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczNTUzMzE1LCJpIjoiYjRiNjJlYmUwODllMTFmMWFhZDUzNDM2YWMxMjAwZTkiLCJpZF9uIjoiMDQzNeaJi-acuueUqOaItyN5SFNrTXQiLCJtc2ciOm51bGwsInBpZCI6IjAzMWNlZjU4LTg3YjMtNDc1NC05OWQ2LWU0MDg0NTMxYTA2YyIsInNzX24iOiIwNDM15omL5py655So5oi3I3lIU2tNdCIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.auz54eQxWqgK22fBNidnPyxOeL2BbGla5hMlUlxYFAuGkayZZsJaSk0MMMlDpoV3YNbK0T7Qegyt6-vY3O8j2oRBFzEy28rOeKNgFZVrgWWwcVuIlLtwcsVtVeec95_gy6SsaYB31jwZS_1lgD-ObA9m24IuHMXqlaBChTvRFmvbpeChRPJ4Mh5Zzz2doPe4brd-coNIRy4oQN8FKsbcw6rbbuJgvT4B-E3ftuEdx69s2qQKXx6KNf_pFL6FTmItJVSMTAIqciDvWXoxPqrJ48OEzhavR00z4iKjalHoaIpuJswDU_6FlsMGJrg9bpBaiFUhNpMEajNWVpU2jlW0Cw; login_scene=11; volcengineLoginMethod=pwd; csrfToken=bebb2ad0f9bc027de95b0d2f18450aa9; csrfToken=bebb2ad0f9bc027de95b0d2f18450aa9; gfkadpd=520918,36088; __tea_cache_tokens_3569={%22web_id%22:%227606220745165375022%22%2C%22user_unique_id%22:%227606220745165375022%22%2C%22timestamp%22:1770961317447%2C%22_type_%22:%22default%22}; s_v_web_id=verify_mlkgnbq9_5AbTkXNC_EYAi_4bTQ_9qnK_aJ8hRAcPggyM"""
    model = "doubao-seed"
    prompt = "鸭子放在T恤上"
    image = [
            "https://v3.fal.media/files/penguin/XoW0qavfF-ahg-jX4BMyL_image.webp",
             "https://v3.fal.media/files/tiger/bml6YA7DWJXOigadvxk75_image.webp"
  ]

    request = ImageRequest(
        model=model, n=1,
        prompt=prompt,
                           size='4096x2048',

        image=image
                           )

    arun(generate(request=request, api_key=api_key))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : image
# @Time         : 2022/6/15 上午11:33
# @Author       : yuanjie
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://blog.csdn.net/Q_452086192/article/details/125014538
# https://www.jb51.net/article/207138.htm

import mimetypes
from PIL import Image, ImageDraw

from meutils.pipe import *
from meutils.io.files_utils import to_url, to_bytes, to_url_fal

from PIL import Image


# get_image_format 判断图片类型
async def image_resize(image, target_ratio: Union[float, str], output_path, fill_color=(0, 0, 0)):
    """
    将图片缩放到目标比例，保持完整内容，不足部分填充背景色

    :param target_ratio: 目标宽高比 (width/height)，如 16/9
    """
    w = h = 1
    if isinstance(target_ratio, str):

        if 'x' in target_ratio:
            w, h = map(int, target_ratio.split('x'))
        elif ':' in target_ratio:
            w, h = map(int, target_ratio.split(':'))

        target_ratio = w / h

    _ = await to_bytes(image)
    img = Image.open(io.BytesIO(_))

    img_ratio = img.width / img.height

    # 计算缩放后的尺寸
    if img_ratio > target_ratio:
        # 原图更宽，以宽度为基准
        new_width = img.width
        new_height = int(img.width / target_ratio)
    else:
        # 原图更高或正好，以高度为基准
        new_height = img.height
        new_width = int(img.height * target_ratio)

    if w > 32:
        new_width, new_height = w, h

    # 创建目标尺寸画布并居中粘贴
    result = Image.new('RGB', (new_width, new_height), fill_color)

    offset_x = (new_width - img.width) // 2
    offset_y = (new_height - img.height) // 2
    result.paste(img, (offset_x, offset_y))

    if 'base64' in output_path:
        format = "JPEG"
        # 创建一个字节流缓冲区
        buffered = io.BytesIO()
        # 将图像保存到缓冲区
        result.save(buffered, format)
        # 获取缓冲区的字节内容
        img_bytes = buffered.getvalue()
        # 将字节内容编码为Base64字符串
        img_base64 = base64.b64encode(img_bytes).decode("utf-8")
        return f"data:image/{format.lower()};base64,{img_base64}"

    elif "url" in output_path:
        format = "JPEG"
        # 创建一个字节流缓冲区
        buffered = io.BytesIO()
        # 将图像保存到缓冲区
        result.save(buffered, format)
        # 获取缓冲区的字节内容
        img_bytes = buffered.getvalue()

        if output_path == "fal-url":
            return await to_url_fal(img_bytes, f"{shortuuid.random()}.jpg")

        return await to_url(img_bytes, f"{shortuuid.random()}.jpg")


    else:
        result.save(output_path)
        print(f"✅ {image} -> {output_path}")
        print(f"   原尺寸: {img.width}x{img.height} (比例: {img_ratio:.2f})")
        print(f"   新尺寸: {new_width}x{new_height} (比例: {target_ratio:.2f})")
        return result


async def describe_image(image: Union[str, bytes]):
    """
    图片转base64  webp会报错
    :param image: 图片路径或图片对象
    :return: base64字符串
    """
    _ = await to_bytes(image)
    img = Image.open(io.BytesIO(_))

    info = {
        'format': img.format,  # 图片格式
        'mode': img.mode,  # 颜色模式

        'width': img.width,  # 宽度
        'height': img.height,  # 高度
        'size': img.size,  # (宽度, 高度)

        'is_animated': getattr(img, 'is_animated', False),  # 是否是动图
        'n_frames': getattr(img, 'n_frames', 1),  # 帧数
        'info': img.info,  # 图片附加信息
    }
    return info


def crop_polygon(image: Union[str, bytes], outline_points, inline_points):
    if isinstance(image, bytes):
        image = io.BytesIO(image)

    # 打开图像
    img = Image.open(image)

    # 创建一个与原图大小相同的黑色遮罩
    mask = Image.new('L', img.size, 0)

    # 在遮罩上绘制白色多边形
    for points in outline_points:
        ImageDraw.Draw(mask).polygon(points, outline=1, fill=255)

    for points in inline_points:
        ImageDraw.Draw(mask).polygon(points, outline=1, fill=0)

    # 将遮罩应用到原图
    output = Image.new('RGBA', img.size, (0, 0, 0, 0))
    output.paste(img, (0, 0), mask)

    # # 将 PIL Image 转换为字节
    # buffer = io.BytesIO()
    # output.save(buffer, format="PNG")
    # byte_data = buffer.getvalue()
    #
    # return byte_data
    return output


def img2bytes(img, format=None):
    """

    @param img: Optional[Image | np.array]
    @param format:
    @return:
    """
    # cv2 = try_import("cv2", pip_name="opencv-python")
    import cv2

    # if isinstance(img, Image):
    #     img = np.asarray(img)

    # a = cv2.cvtColor(a, cv2.COLOR_RGB2BGR)
    _, img_encode = cv2.imencode(format, img)

    return img_encode.tobytes()


def bytes2img(_bytes):
    import cv2

    np_arr = np.frombuffer(_bytes, dtype=np.uint8)
    # np.asarray(bytearray(bs), dtype=np.uint8)
    img = cv2.imdecode(np_arr, cv2.IMREAD_COLOR)
    return img


def image_read(filename):
    import cv2

    filename = str(filename)
    _bytes = b''
    if filename.startswith('http'):
        _bytes = requests.get(filename, stream=True).content

    elif Path(filename).exists():
        _bytes = Path(filename).read_bytes()

    if _bytes:
        try:
            np_arr = np.frombuffer(_bytes, dtype=np.uint8)
            # np.asarray(bytearray(bs), dtype=np.uint8)
            img = cv2.imdecode(np_arr, cv2.IMREAD_COLOR)
            return img
        except Exception as e:
            logger.warning(e)
            return np.asarray((Image.open(io.BytesIO(_bytes)).convert('RGB')))


def base64_to_image(base64_str):
    """
    import jmespath
    d = json.load(open('clients.ipynb'))
    base64_str = jmespath.search('cells[*].attachments', d)[0]['27fa29dd-5f0a-48b0-8e76-334e70a23595.png']['image/png']

    """
    import cv2
    # 传入为RGB格式下的base64，传出为RGB格式的numpy矩阵
    byte_data = base64.b64decode(base64_str)  # 将base64转换为二进制
    encode_image = np.asarray(bytearray(byte_data), dtype="uint8")  # 二进制转换为一维数组
    img_array = cv2.imdecode(encode_image, cv2.IMREAD_COLOR)  # 用cv2解码为三通道矩阵
    img_array = cv2.cvtColor(img_array, cv2.COLOR_BGR2RGB)  # BGR2RGB
    return img_array


def image_to_base64(image_path_or_url, for_image_url: bool = True):
    content_type = mimetypes.guess_type(image_path_or_url)[0] or "image/jpeg"
    logger.debug(content_type)

    if image_path_or_url.startswith('http'):
        data = httpx.get(image_path_or_url, follow_redirects=True, timeout=100).content
    else:
        data = Path(image_path_or_url).read_bytes()

    _ = base64.b64encode(data).decode('utf-8')
    if for_image_url:
        _ = f"data:{content_type};base64,{_}"
    return _


def base64_to_bytes(base64_image_string):
    """
    # 将字节数据写入图片文件
    image_data = base64_to_bytes(...)
    with open(filename, 'wb') as file:
        file.write(image_data)
    """
    return base64.b64decode(base64_image_string.split(",", 1)[-1])


@alru_cache()
async def image2nowatermark_image(url, picinfo: str = '', oss: str = 'glm', token: Optional[str] = None):
    if not url: return

    from meutils.apis.baidu.bdaitpzs import create_task, BDAITPZSRequest

    # response = await httpx.AsyncClient(timeout=100, headers=headers, follow_redirects=True).get(url)
    # response.raise_for_status()

    # 去水印
    # request = BDAITPZSRequest(original_url=url, thumb_url=url) # 网络错误
    request = BDAITPZSRequest(picInfo=image_to_base64(url), picInfo2=picinfo)
    if picinfo:
        request.type = 2
        request.picInfo2 = picinfo

    data = await create_task(request, is_async=False, token=token)
    base64_string = data['picArr'][-1]['src']
    file = base64_to_bytes(base64_string)

    if oss == 'kling':  # kuaishou
        from meutils.apis.kuaishou import klingai

        file_task = await klingai.upload(file, cookie=token)
        return file_task and file_task.url

    else:
        url = await to_url(file) or url
        return url


# alias
base64_to_img = base64_to_image

if __name__ == '__main__':
    url = "https://i1.mifile.cn/f/i/mioffice/img/slogan_5.png?1604383825042"
    #
    # print(image_read(url))
    # base64_image_string = image_to_base64("img.png").split(",")[1]
    # # print(base64_to_bytes(image_to_base64("img.png")))
    # image_data = base64.b64decode(base64_image_string)
    #
    # with open("demo1.png", 'wb') as file:
    #     file.write(base64_to_bytes(image_to_base64("img.png")))

    # import mimetypes

    # print(mimetypes.guess_type('img.webp')[0])
    # image_to_base64(url)
    s = """
    """
    # base64_to_file(s, 'x.png')

    # url = "https://sfile.chatglm.cn/chatglm-videoserver/image/50/5049bae9.png"
    url = "https://oss.ffire.cc/files/kling_watermark.png"
    # arun(image2nowatermark_image(url))
    # arun(url2url(url))

    from meutils.schemas.baidu_types import PICINFO2_RIGHT_BOTTOM

    url = "https://s22-def.ap4r.com/bs2/upload-ylab-stunt-sgp/se/ai_portal_sgp_queue_mmu_img2img_aiweb/7de17faa-cc11-48a6-b94a-e80fe7a34841/1.png"

    # arun(image2nowatermark_image(url, picinfo=PICINFO2_RIGHT_BOTTOM))
    # with timer():
    #     arun(describe_image("https://oss.ffire.cc/files/kling_watermark.png"))

    image = "https://s3.ffire.cc/files/jimeng.jpg"
    image = "https://storage.googleapis.com/falserverless/example_inputs/veo31-r2v-input-1.png"

    output_path = "output_path.jpg"
    # output_path = 'base64'
    # output_path = 'url'

    # arun(image_resize(image, target_ratio="1280x720", output_path=output_path))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : x
# @Time         : 2024/11/25 12:23
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
from gradio_client import Client, handle_file

client = Client("https://s5k.cn/api/v1/studio/Kwai-Kolors/Kolors-Virtual-Try-On/gradio/",
                # hf_token="9f8db42c-1a54-4e72-9640-46f12754853f"
                hf_token="8ee3c18e-9804-413f-b960-45d23f409281"

                )
result = client.predict(
		person_img=handle_file('https://raw.githubusercontent.com/gradio-app/gradio/main/test/test_files/bus.png'),
		garment_img=handle_file('https://raw.githubusercontent.com/gradio-app/gradio/main/test/test_files/bus.png'),
		seed=0,
		randomize_seed=True,
		api_name="/tryon"
)
print(result)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : common
# @Time         : 2023/5/26 09:23
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://geek-docs.com/fastapi/fastapi-questions/279_fastapi_uvicorn_python_run_both_http_and_https.html
# 请求限制 https://github.com/Unstructured-IO/pipeline-paddleocr/blob/main/prepline_paddleocr/api/paddleocr.py
# todo: 增加apikey、增加调用频次
# 中间件 https://mp.weixin.qq.com/s/1XS5hSKEVaTeUH8oXik8Hw

# check api https://github.com/eosphoros-ai/DB-GPT/blob/04af30e3db9bf5e7a60ab55ade01dc8ddeba06f8/dbgpt/app/openapi/api_v2.py#L46

from meutils.pipe import *
from fastapi import FastAPI, APIRouter
from fastapi.middleware.cors import CORSMiddleware
from fastapi.exceptions import RequestValidationError, HTTPException

from meutils.serving.fastapi.exceptions.http_error import http_error_handler, chatfire_api_exception_handler
from meutils.serving.fastapi.exceptions.validation_error import http422_error_handler, validation_exception_handler



class App(FastAPI):

    def __init__(self, **kwargs):
        super().__init__(**kwargs)

        # openapi_url = "/api/v1/openapi.json"
        self.servers = [{"url": ""}]

        self.add_middleware(
            CORSMiddleware,
            allow_origins=['*'],
            allow_credentials=True,
            allow_methods=['*'],
            allow_headers=['*'],
        )

        # 服务器内部错误 500
        self.add_exception_handler(Exception, chatfire_api_exception_handler)  # 500

        # HTTPException
        self.add_exception_handler(HTTPException, http_error_handler)

        # RequestValidationError
        self.add_exception_handler(RequestValidationError, http422_error_handler)
        self.add_exception_handler(RequestValidationError, validation_exception_handler)  # 500

    def include_router(self, router, prefix='', **kwargs):
        """
            from fastapi import FastAPI, APIRouter
            router = APIRouter(route_class=LoggingRoute)

        :param router:
        :param prefix:
        :param kwargs:
        :return:
        """

        super().include_router(router, prefix=prefix, **kwargs)

    def run(self, app=None, host="0.0.0.0", port=8000, workers=1, access_log=True, reload=False, **kwargs):
        """

        :param app:
            f"{Path(__file__).stem}:{app}"
            app字符串可开启热更新 reload
        :param host:
        :param port:
        :param workers:
        :param access_log:
        :param kwargs:
        :return:
        """

        import uvicorn

        uvicorn.config.LOGGING_CONFIG['formatters']['access']['fmt'] = f"""
        🔥 %(asctime)s - %(levelprefix)s %(client_addr)s - "%(request_line)s" %(status_code)s
        """.strip()
        uvicorn.run(
            app if app else self,  #
            host=host, port=port, workers=workers, access_log=access_log, reload=reload, app_dir=None,
            **kwargs
        )

    def sentry_init(self):
        """https://qyyshop.com/info/767857.html"""
        import sentry_sdk

        sentry_sdk.init(
            dsn="https://YourPublicKey@o0.ingest.sentry.io/0",
            enable_tracing=True,
        )


if __name__ == '__main__':
    from fastapi import FastAPI, APIRouter, Request
    from meutils.serving.fastapi.utils import limit

    app = App()
    router = APIRouter()  # 怎么限流？


    # @router.get('/xx', name='xxxx')
    # @limit(limit_value='3/minute', error_message='请联系我')
    # def f(request: Request):
    #     return {'1': '11'}

    @app.get("/test")
    def test_endpoint():
        # 这里故意触发一个HTTPException来演示错误处理
        raise HTTPException(status_code=505, detail="Item not found")

        # raise Exception("test")


    app.include_router(router)
    app.run(port=8899)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : hailuo
# @Time         : 2024/12/6 09:05
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 


from meutils.async_utils import async_to_sync_pro
from meutils.async_task import worker, shared_task
from meutils.apis.hailuoai.videos import VideoRequest, create_task as remote_create_task, get_task


@shared_task(pydantic=True, retry_kwargs={'max_retries': 10, 'countdown': 10})
@async_to_sync_pro
async def create_task(request, **kwargs):
    if isinstance(request, dict):
        request = VideoRequest(**request)

    response = await remote_create_task(request)
    return response.model_dump()



import io

from PIL import Image
import os

from meutils.io.files_utils import to_bytes


async def get_image_format(file):
    file = await to_bytes(file)
    file = io.BytesIO(file)

    try:
        with Image.open(file) as img:
            logger.debug(img.mode)
            # format 属性返回大写的格式名，如 'JPEG', 'PNG', 'GIF' 等
            return img.format
    except Exception as e:
        return f"错误: {e}"


if __name__ == '__main__':
    from meutils.pipe import *

    url = "https://s3.ffire.cc/cdn/20260131/wXfXShqBw3uW5etgvsaL4v.jpeg"
    url = "wXfXShqBw3uW5etgvsaL4v.jpeg"
    url = "https://s3.ffire.cc/cdn/20260131/sNQLXjrfPFph26no3Jizvs.jpeg"
    url = "https://s3.ffire.cc/files/jimeng.jpg"
    url = "https://v3.fal.media/files/penguin/XoW0qavfF-ahg-jX4BMyL_image.webp"
    url = 'https://i.pinimg.com/736x/81/14/8a/81148a56c93e194c44ee7e027a19307b.jpg'
    url = "https://s3.ffire.cc/cdn/20260202/tecv2iqCHpnC493USmRFDw.jpeg"
    arun(get_image_format(url))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : chat
# @Time         : 2025/4/10 16:06
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
import os

from meutils.pipe import *
from meutils.io.files_utils import to_base64
from meutils.llm.clients import AsyncOpenAI, zhipuai_client
from meutils.llm.openai_utils import to_openai_params
from meutils.llm.token_pool import TokenPool, create_volc_request

from meutils.schemas.openai_types import CompletionRequest, CompletionUsage

from meutils.apis.proxy.kdlapi import get_one_proxy
from openai import APIStatusError

VLM = "glm-4.6v-flash"
class Completions(object):

    def __init__(
            self,
            base_url: Optional[str] = None,
            api_key: Optional[str] = None,
            http_client: Optional[httpx.AsyncClient] = None,
            mode: Optional[str] = None,  # tokens 计算模式
    ):
        self.mode = mode

        self.base_url = base_url
        self.api_key = api_key

        self.client = AsyncOpenAI(base_url=self.base_url, api_key=self.api_key, http_client=http_client)

    async def create(self, request: CompletionRequest):
        if self.mode == "tokens" and any(i in self.base_url for i in {"volc", "doubao"}):
            request, mini_api_key = await create_volc_request(request)
            self.api_key = mini_api_key

        ###########################################################################
        # 开启视觉模型
        if not any(i in request.model.lower() for i in ["v-", "vl", "ui", 'vision', 'doubao-seed']) and (
                urls := request.last_urls.get("image_url")):
            # logger.debug(request)
            if request.model.startswith(("gemini",)):

                if urls[-1].startswith("http"):
                    base64_list = await to_base64(urls, content_type="image/png")
                else:
                    base64_list = urls  # 仅支持base64 todo: tokens怎么计算的

                request.messages = [
                    {
                        'role': 'user',
                        'content': [
                            {
                                'type': 'text',
                                'text': request.last_user_content
                            },
                            *[
                                {
                                    'type': 'image_url',
                                    'image_url': {
                                        'url': base64_data
                                    }
                                }
                                for base64_data in base64_list
                            ]

                        ]
                    }
                ]
            else:
                request.model = VLM
                request.max_tokens = None
                self.client = zhipuai_client

        elif "deepseek-r" in request.model:  # 参数覆盖即可
            request.separate_reasoning = True  # pp
            # """Error code: 403 - {'code': 403, 'reason': 'NOT_ENOUGH_BALANCE', 'message': 'not enough balance', 'metadata': {}}"""
        ###########################################################################

        data = to_openai_params(request)
        # if 'gemini' in request.model:
        #     data.pop("seed", None)
        #     data.pop("presence_penalty", None)
        #     data.pop("frequency_penalty", None)
        #     data.pop("extra_body", None)
        #
        #     if "thinking" in request.model:
        #         data['model'] = data['model'].removesuffix("-thinking")  # 开启思考
        #         data['reasoning_effort'] = 'low'

        # logger.debug(data)
        try:
            response = await self.client.chat.completions.create(**data)

            # tokens
            if self.mode == "tokens" and not request.stream and response.usage:
                total_tokens = response.usage.total_tokens
                await TokenPool('volc').incr_tokens(request.model, self.api_key, total_tokens)

            return response

        except APIStatusError as e:
            logger.debug(e)
            # logger.debug(e.response.json())
            # logger.debug(e.response.status_code)
            if e.response.status_code > 403:
                if self.mode == "tokens" and any(i in self.base_url for i in {"volc", "doubao"}):  # 火山轮询
                    total_tokens = 10 ** 7
                    if e.code == "AccountOverdueError":  # 403
                        pass
                    elif e.code == "ModelNotOpen":  # 404 大概率账号失效 软删除
                        total_tokens = 10 ** 8

                    await TokenPool('volc').incr_tokens(request.model, api_key, total_tokens)

                elif any(i in self.base_url for i in {"siliconflow", "modelscope"}):  # 代理
                    proxy = await get_one_proxy()
                    client = AsyncOpenAI(
                        base_url=self.base_url,
                        api_key=self.api_key,
                        http_client=httpx.AsyncClient(proxy=proxy, timeout=300)
                    )
                    response = await client.chat.completions.create(**data)
                    return response

            raise e


if __name__ == '__main__':
    # 测试 token 1800

    request = CompletionRequest(
        # model="gemini-2.0-flash",
        # model="glm-4-flash",
        # model="deepseek-ai/DeepSeek-V3",
        # model="Qwen/Qwen3-8B1",
        # model="Qwen/Qwen3-8B1",
        # model="doubao-1-5-thinking",
        # model="doubao-1-5",
        model="doubao-seed",
        # model="doubao-seed-1-6-250615",

        thinking={"type": "disabled"},
        messages=[
            {
                "role": "system",
                "content": [
                    {
                        "type": "text",
                        "text": "你是一个数学助手，擅长解决复杂的数学问题。"
                    }
                ]
            },
            # {"role": "user", "content": "你好"},
            {"role": "user", "content": [
                {
                    "type": "text",
                    "text": "解释下" * 1
                },
                # {
                #     "image_url": {
                #         # "detail": "auto",
                #         "url": "https://oss.ffire.cc/files/kling_watermark.png"
                #     },
                #     "type": "image_url"
                # }
            ]}
        ],
        # stream=False,
        # stream=True,

        max_tokens=10,
    )
    # arun(Completions().create(request))
    # d = {
    #     "model": "gemini-2.5-pro-exp-03-25",
    #     "messages": [
    #         {
    #             "content": [
    #                 {
    #                     "text": "The following is an open-ended problem from an International Math competition. Please calculate the answer according to the given requirements and the information provided. Please use LaTeX format to represent the variables and formulas used in the solution process and results. Please end your solution with \"So the final answer is \boxed{multiple answers connected with commas}(unit).\" and give the result explicitly, note that the unit of the answer should not be included in \boxed{}.\nConsider the following system of equations in which all logarithms have base 10:\n\n$$\n\begin{aligned}\n(\log x)(\log y)-3 \log 5 y-\log 8 x & =a \\n(\log y)(\log z)-4 \log 5 y-\log 16 z & =b \\n(\log z)(\log x)-4 \log 8 x-3 \log 625 z & =c\n\end{aligned}\n$$\nIf $a=-4, b=4$, and $c=-18$, solve the system of equations.",
    #                     "type": "text"
    #                 },
    #                 {
    #                     "image_url": {
    #                         "detail": "low",
    #                         "url": "data:image/jpeg;base64,/9j/4AAQSkZJRgABAQAAAQABAAD/2wBDAAgGBgcGBQgHBwcJCQgKDBQNDAsLDBkSEw8UHRofHh0aHBwgJC4nICIsIxwcKDcpLDAxNDQ0Hyc5PTgyPC4zNDL/2wBDAQkJCQwLDBgNDRgyIRwhMjIyMjIyMjIyMjIyMjIyMjIyMjIyMjIyMjIyMjIyMjIyMjIyMjIyMjIyMjIyMjIyMjL/wAARCABAAEADASIAAhEBAxEB/8QAHwAAAQUBAQEBAQEAAAAAAAAAAAECAwQFBgcICQoL/8QAtRAAAgEDAwIEAwUFBAQAAAF9AQIDAAQRBRIhMUEGE1FhByJxFDKBkaEII0KxwRVS0fAkM2JyggkKFhcYGRolJicoKSo0NTY3ODk6Q0RFRkdISUpTVFVWV1hZWmNkZWZnaGlqc3R1dnd4eXqDhIWGh4iJipKTlJWWl5iZmqKjpKWmp6ipqrKztLW2t7i5usLDxMXGx8jJytLT1NXW19jZ2uHi4+Tl5ufo6erx8vP09fb3+Pn6/8QAHwEAAwEBAQEBAQEBAQAAAAAAAAECAwQFBgcICQoL/8QAtREAAgECBAQDBAcFBAQAAQJ3AAECAxEEBSExBhJBUQdhcRMiMoEIFEKRobHBCSMzUvAVYnLRChYkNOEl8RcYGRomJygpKjU2Nzg5OkNERUZHSElKU1RVVldYWVpjZGVmZ2hpanN0dXZ3eHl6goOEhYaHiImKkpOUlZaXmJmaoqOkpaanqKmqsrO0tba3uLm6wsPExcbHyMnK0tPU1dbX2Nna4uPk5ebn6Onq8vP09fb3+Pn6/9oADAMBAAIRAxEAPwD3+iiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigD//2Q=="
    #                     },
    #                     "type": "image_url"
    #                 }
    #             ],
    #             "role": "user"
    #         }
    #     ],
    #     "stream": False,
    #     "top_p": 0.7,
    #     "temperature": 0.7,
    #     "n": 1
    # }

    d = {
        "model": "gemini-2.5-pro-exp-03-25",
        # "model": "gemini-2.5-flash-preview-04-17",
        # "model": "gemini-2.5-pro-exp-03-25-thinking",

        "messages": [
            {
                "content": [
                    {
                        "text": "9个8如何加减乘除运直得到1000",
                        "type": "text"
                    },

                ],
                "role": "user"
            }
        ],
        "stream": False,
        "top_p": 0.7,
        "temperature": 0.7,
        "n": 1,
        "reasoning_effort": None
    }
    # api_key = os.getenv("GOOGLE_API_KEY")
    # base_url = os.getenv("GOOGLE_BASE_URL")
    # arun(Completions(api_key=api_key, base_url=base_url).create(request.construct(**d)))

    # request = CompletionRequest(
    #     # model="gemini-2.0-flash",
    #     # model="glm-4-flash",
    #     model="deepseek/deepseek-r1-turbo",
    #
    #     messages=[
    #
    #         {"role": "user", "content": "你好"},
    #
    #     ],
    #     stream=False,
    #     max_tokens=None,
    # )
    # api_key = os.getenv("SILICONFLOW_API_KEY")
    # base_url = "https://api.siliconflow.cn"
    # arun(Completions(api_key=api_key, base_url=base_url).create(request))

    api_key = os.getenv("VOLC_API_KEY")
    base_url = os.getenv("VOLC_BASE_URL")


    async def main():
        async for i in await Completions(api_key=api_key, base_url=base_url).create(request):
            logger.debug(i)


    arun(Completions(api_key=api_key, base_url=base_url).create(request))

    # arun(main())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : lip_sync
# @Time         : 2025/1/3 16:17
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
"""
1. 上传图片 image_to_avatar检测
2. 上传视频 video_to_avatar检测
3. 上传音频+创建任务

"""
import asyncio
import json

from meutils.apis.jimeng.doubao_utils import generate_jimeng_params
from meutils.pipe import *
from meutils.str_utils.json_utils import json_path

from meutils.schemas.jimeng_types import BASE_URL
from meutils.schemas.video_types import SoraVideoRequest

from meutils.schemas.task_types import TaskResponse
from meutils.apis.jimeng.common import get_headers, check_token
from meutils.apis.jimeng.files import upload_for_image, upload_for_video

from fake_useragent import UserAgent

ua = UserAgent()


async def get_task(task_id: str, token: str = "916fed81175f5186a2c05375699ea40d"):
    task_ids = task_id.split()

    url = "/mweb/v1/mget_generate_task"
    url = "/mweb/v1/get_history_queue_info"
    headers = get_headers(url, token)

    payload = {"task_id_list": task_ids}
    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.post(url, json=payload)
        response.raise_for_status()
        data = response.json()
        logger.debug(bjson(data))

        if video_urls := json_path(data, "$..video_url"):  # 角色检测 create_realman_avatar

            task_data = dict(zip(["video"] * len(video_urls), video_urls))
            response = TaskResponse(task_id=task_id, data=task_data, status="success")
            return response

        else:
            response = TaskResponse(task_id=task_id)
            if (
                    (fail_codes := json_path(data, "$..fail_code"))
                    and fail_codes[-1] != "0"
                    and (messages := json_path(data, "$..fail_msg"))
            ):
                response.message = f"{str(messages).lower().replace('success', '')}:{fail_codes}"
                response.status = "fail"
                return response

            if will_cost := json_path(data, "$..will_cost"):
                response.will_cost = will_cost[0]

            if video_urls := json_path(data, "$..[360p,480p,720p].video_url"):
                response.data = [{"video": _} for _ in video_urls]
                response.status = "success"

            response.fail_code = fail_codes and fail_codes[-1]
            return response


async def create_task(request: SoraVideoRequest, token: Optional[str] = None):
    url = "/mweb/v1/aigc_draft/generate"

    headers = get_headers(url, token)
    params = generate_jimeng_params()

    request.duration = int(request.seconds or 1)

    payload = {
        "extend": {
            "root_model": "dreamina_seedance_40_pro",
            "m_video_commerce_info": {
                "benefit_type": "dreamina_video_seedance_20_pro",
                "resource_id": "generate_video",
                "resource_id_type": "str",
                "resource_sub_type": "aigc"
            },
            "m_video_commerce_info_list": [
                {
                    "benefit_type": "dreamina_video_seedance_20_pro",
                    "resource_id": "generate_video",
                    "resource_id_type": "str",
                    "resource_sub_type": "aigc"
                }
            ]
        },
        "submit_id": "9c50c667-41a1-4c54-a517-4be96919e85b",
        "metrics_extra": "{\"promptSource\":\"custom\",\"isDefaultSeed\":1,\"originSubmitId\":\"9c50c667-41a1-4c54-a517-4be96919e85b\",\"isRegenerate\":false,\"enterFrom\":\"click\",\"position\":\"page_bottom_box\",\"functionMode\":\"first_last_frames\",\"sceneOptions\":\"[{\\\"type\\\":\\\"video\\\",\\\"scene\\\":\\\"BasicVideoGenerateButton\\\",\\\"modelReqKey\\\":\\\"dreamina_seedance_40_pro\\\",\\\"videoDuration\\\":9,\\\"reportParams\\\":{\\\"enterSource\\\":\\\"generate\\\",\\\"vipSource\\\":\\\"generate\\\",\\\"extraVipFunctionKey\\\":\\\"dreamina_seedance_40_pro\\\",\\\"useVipFunctionDetailsReporterHoc\\\":true},\\\"materialTypes\\\":[]}]\"}",
        "draft_content": "{\"type\":\"draft\",\"id\":\"94aa382f-ce99-4308-3acd-6c6d33c780e5\",\"min_version\":\"3.0.5\",\"min_features\":[],\"is_from_tsn\":true,\"version\":\"3.3.9\",\"main_component_id\":\"9bdf4947-1f2b-87aa-9b23-240faa0bef8f\",\"component_list\":[{\"type\":\"video_base_component\",\"id\":\"9bdf4947-1f2b-87aa-9b23-240faa0bef8f\",\"min_version\":\"1.0.0\",\"aigc_mode\":\"workbench\",\"metadata\":{\"type\":\"\",\"id\":\"90515d13-4557-23c3-9dca-6f6fb6194d40\",\"created_platform\":3,\"created_platform_version\":\"\",\"created_time_in_ms\":\"1770692785855\",\"created_did\":\"\"},\"generate_type\":\"gen_video\",\"abilities\":{\"type\":\"\",\"id\":\"e2458f1a-0615-50a4-44d7-0350cac452b8\",\"gen_video\":{\"type\":\"\",\"id\":\"6ad3bae5-4562-2cb8-eaa3-9582ddf5fac8\",\"text_to_video_params\":{\"type\":\"\",\"id\":\"3fe8633d-0e29-3a58-5648-7221bd7f9378\",\"video_gen_inputs\":[{\"type\":\"\",\"id\":\"47410404-3b72-6e26-474a-9896806c9f38\",\"min_version\":\"3.0.5\",\"prompt\":\"a cat\",\"video_mode\":2,\"fps\":24,\"duration_ms\":9000,\"idip_meta_list\":[]}],\"video_aspect_ratio\":\"16:9\",\"seed\":301214761,\"model_req_key\":\"dreamina_seedance_40_pro\",\"priority\":0},\"video_task_extra\":\"{\\\"promptSource\\\":\\\"custom\\\",\\\"isDefaultSeed\\\":1,\\\"originSubmitId\\\":\\\"9c50c667-41a1-4c54-a517-4be96919e85b\\\",\\\"isRegenerate\\\":false,\\\"enterFrom\\\":\\\"click\\\",\\\"position\\\":\\\"page_bottom_box\\\",\\\"functionMode\\\":\\\"first_last_frames\\\",\\\"sceneOptions\\\":\\\"[{\\\\\\\"type\\\\\\\":\\\\\\\"video\\\\\\\",\\\\\\\"scene\\\\\\\":\\\\\\\"BasicVideoGenerateButton\\\\\\\",\\\\\\\"modelReqKey\\\\\\\":\\\\\\\"dreamina_seedance_40_pro\\\\\\\",\\\\\\\"videoDuration\\\\\\\":9,\\\\\\\"reportParams\\\\\\\":{\\\\\\\"enterSource\\\\\\\":\\\\\\\"generate\\\\\\\",\\\\\\\"vipSource\\\\\\\":\\\\\\\"generate\\\\\\\",\\\\\\\"extraVipFunctionKey\\\\\\\":\\\\\\\"dreamina_seedance_40_pro\\\\\\\",\\\\\\\"useVipFunctionDetailsReporterHoc\\\\\\\":true},\\\\\\\"materialTypes\\\\\\\":[]}]\\\"}\"}},\"process_type\":1}]}",
        "http_common_info": {
            "aid": 513695
        }
    }

    payload['submit_id'] = str(uuid.uuid4())

    scene_options = [
        {
            "type": "video",
            "scene": "BasicVideoGenerateButton",
            "modelReqKey": "dreamina_seedance_40_pro",
            "videoDuration": request.duration,
            "reportParams": {
                "enterSource": "generate",
                "vipSource": "generate",
                "extraVipFunctionKey": "dreamina_seedance_40_pro",
                "useVipFunctionDetailsReporterHoc": True
            },
            "materialTypes": []
        }
    ]
    metrics_extra = {
        "promptSource": "custom",
        "isDefaultSeed": 1,
        "originSubmitId": payload['submit_id'],
        "isRegenerate": False,
        "enterFrom": "click",
        "position": "page_bottom_box",
        "functionMode": "first_last_frames",
        "sceneOptions": json.dumps(scene_options)
    }

    payload["metrics_extra"] = json.dumps(metrics_extra)

    video_task_extra = {
        "promptSource": "custom",
        "isDefaultSeed": 1,
        "originSubmitId": payload['submit_id'],
        "isRegenerate": False,
        "enterFrom": "click",
        "position": "page_bottom_box",
        "functionMode": "first_last_frames",
        "sceneOptions": metrics_extra["sceneOptions"]
    }
    #
    main_component_id = str(uuid.uuid4())
    #
    draft_content = {
        "type": "draft",
        "id": str(uuid.uuid4()),
        "min_version": "3.0.5",
        "min_features": [],
        "is_from_tsn": True,
        "version": "3.3.9",
        "main_component_id": main_component_id,
        "component_list": [
            {
                "type": "video_base_component",
                "id": main_component_id,
                "min_version": "1.0.0",
                "aigc_mode": "workbench",
                "metadata": {
                    "type": "",
                    "id": str(uuid.uuid4()),
                    "created_platform": 3,
                    "created_platform_version": "",
                    "created_time_in_ms": "1770691641752",
                    "created_did": ""
                },
                "generate_type": "gen_video",
                "abilities": {
                    "type": "",
                    "id": str(uuid.uuid4()),
                    "gen_video": {
                        "type": "",
                        "id": str(uuid.uuid4()),
                        "text_to_video_params": {
                            "type": "",
                            "id": str(uuid.uuid4()),
                            "video_gen_inputs": [
                                {
                                    "type": "",
                                    "id": str(uuid.uuid4()),
                                    "min_version": "3.0.5",
                                    "prompt": request.prompt,
                                    "video_mode": 2,
                                    "fps": 24,
                                    "duration_ms": request.duration * 1000,
                                    "idip_meta_list": []
                                }
                            ],
                            "video_aspect_ratio": request.aspect_ratio,
                            "seed": 2868096692,
                            "model_req_key": "dreamina_seedance_40_pro",
                            "priority": 0
                        },
                        "video_task_extra": json.dumps(video_task_extra)
                    }
                },
                "process_type": 1
            }
        ]
    }

    payload["draft_content"] = json.dumps(draft_content)

    # if request.image_url:
    #     # image_url = "tos-cn-i-tb4s082cfz/a116c6a9dcbc41b889f9aabdef645456"
    #     image_url = await upload_for_image(request.image_url, token, biz="video")
    #     # vid, uri = await upload_for_video(request.image_url, token)
    #     # logger.debug(f"vid: {vid}, uri: {uri}")
    #     payload['input'].pop('video_aspect_ratio', None)
    #     payload['input']['video_gen_inputs'][0]['first_frame_image'] = {
    #         "width": 1024,
    #         "height": 1024,
    #         "image_uri": image_url
    #     }

    logger.debug(bjson(payload))

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.post(url, json=payload, params=params)
        response.raise_for_status()
        data = response.json()
        logger.debug(bjson(data))

    if task_ids := json_path(data, "$..task.task_id"):
        task_id = task_ids[0]
        return TaskResponse(task_id=task_id, system_fingerprint=token)

    else:
        """
       {
           "ret": "1018",
           "errmsg": "account punish limit ai generate",
           "systime": "1749027488",
           "logid": "202506041658081AB86654C66682A7DE2E",
           "data": null
       }
        """

        raise Exception(data)


if __name__ == '__main__':
    token = None
    api_key = token = "4a7a0a0515b0a972a879170a065c795e"

    request = SoraVideoRequest(
        model="dreamina_seedance_40_pro",
        prompt="笑起来",
        # image_url="https://oss.ffire.cc/files/kling_watermark.png",  # 图生有问题
    )

    # with timer():
    #     r = arun(create_task(request, token=api_key))
    #     print(r)

    # arun(get_task(r.task_id))
    # arun(get_task(r.task_id, "d2d142fc877e696484cc2fc521127b36"))
    task_id = "9022527206924"

    arun(get_task(task_id, token))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : jinja_utils
# @Time         : 2021/3/26 11:47 上午
# @Author       : yuanjie
# @WeChat       : 313303303
# @Software     : PyCharm
# @Description  : https://zhuanlan.zhihu.com/p/152203801

import jinja2

# from jinja2 import Template, Environment, PackageLoader, FileSystemLoader

# from meutils.path_utils import *
# template_path = get_module_path('./templates')
# env = Environment(loader=FileSystemLoader(template_path))
jinja_env = jinja2.Environment(loader=jinja2.PackageLoader('meutils'))
template = jinja_env.get_template('demo.j2')
print(template)
# template = jinja_env.get_template('dsl/dsl_dnn.yml')






#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : videos
# @Time         : 2025/6/11 15:13
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : todo 官方格式

from meutils.pipe import *
from meutils.io.files_utils import to_url, to_base64
from meutils.decorators.retry import retrying
from meutils.apis.oneapi.utils import polling_keys
from meutils.apis.volcengine_apis.utils import upload

from meutils.llm.clients import AsyncClient
from meutils.schemas.openai_types import CompletionRequest
from meutils.schemas.video_types import SoraVideoRequest, Video

BASE_URL = "https://ml-platform-api.console.volcengine.com/ark/bff/api/cn-beijing/2024-01-29"


# "https://ml-platform-api.console.volcengine.com/ark/bff/api/cn-beijing/2024-01-29/CreateVideoGenTask"

class Tasks(object):

    def __init__(self, api_key):
        self.api_key = api_key
        self.csrf_token = api_key.split("csrfToken=")[1].split(';')[0]

        default_headers = {
            "x-csrf-token": self.csrf_token,
            "Cookie": api_key
        }
        self.client = AsyncClient(base_url=BASE_URL, default_headers=default_headers)

    async def create(self, request: SoraVideoRequest):
        payload = {
            "Watermark": False,

            # "CallbackUrl": f"""{os.getenv("WEBHOOK_URL")}/sd1""",
            # "callback_url": f"""{os.getenv("WEBHOOK_URL")}/sd11""",
            # "CallbackURL": f"""{os.getenv("WEBHOOK_URL")}/sd111""",

            "Name": "doubao-seedance-2-0",
            "Prompt": "飞起来",
            "TaskType": "BasicMode",
            "VideoTaskType": "text_to_video",

            "ModelName": "doubao-seedance-2-0",
            "ModelVersion": "260128",
            "Ratio": "adaptive",
            "Resolution": "480p",
            "GroupId": "1-1770783676576",
            "Duration": 5,
            "Seed": -1,
            "EndpointID": "doubao-seedance-2-0-260128",

            "GenerationTimeout": 48,
            "GenerateAudio": True,
            "DurationMode": "duration",
            "OptimizePromptOptions": {
                "EnableWebSearch": False
            },

            # "FirstFrameImageTosLocation": {
            #     "BucketName": "ark-common-storage-prod-cn-beijing",
            #     "ObjectKey": "experience_video/2119812478/0/20260211/3fb89957-0040-4cee-bf55-94214196c1d0.png",
            #     "Url": "https://ark-common-storage-prod-cn-beijing.tos-cn-beijing.volces.com/experience_video/2119812478/0/20260211/3fb89957-0040-4cee-bf55-94214196c1d0.png?X-Tos-Algorithm=TOS4-HMAC-SHA256&X-Tos-Credential=AKLTMjgxMzUwNzliYzdlNDE4MTllYjJjZGVlOWQ3N2M1ZDY%2F20260211%2Fcn-beijing%2Ftos%2Frequest&X-Tos-Date=20260211T042100Z&X-Tos-Expires=604800&X-Tos-Signature=3de95294198e2da85a0d8fc3a7f9c626ad873ceb0b5578eabcc9fefebc7bcf5e&X-Tos-SignedHeaders=host"
            # },
            # "LastFrameImageTosLocation": {
            #     "BucketName": "ark-common-storage-prod-cn-beijing",
            #     "ObjectKey": "experience_video/2119812478/0/20260211/8097768e-a5ae-47a4-858a-09993f8a5213.jpg",
            #     "Url": "https://ark-common-storage-prod-cn-beijing.tos-cn-beijing.volces.com/experience_video/2119812478/0/20260211/8097768e-a5ae-47a4-858a-09993f8a5213.jpg?X-Tos-Algorithm=TOS4-HMAC-SHA256&X-Tos-Credential=AKLTMjgxMzUwNzliYzdlNDE4MTllYjJjZGVlOWQ3N2M1ZDY%2F20260211%2Fcn-beijing%2Ftos%2Frequest&X-Tos-Date=20260211T042107Z&X-Tos-Expires=604800&X-Tos-Signature=372556f8b7e9b97a895eebe14b6eee9ae02aca0d450bb8124a13864d90244304&X-Tos-SignedHeaders=host"
            # },
        }
        ### 映射
        payload["Prompt"] = request.prompt
        payload["Duration"] = int(request.seconds or 4)

        if request.resolution:
            payload["Resolution"] = request.resolution

        if request.aspect_ratio:
            payload["Ratio"] = request.aspect_ratio

        if not request.generate_audio:
            payload["GenerateAudio"] = request.generate_audio

        if request.enhance_prompt:
            payload["OptimizePromptOptions"]["EnableWebSearch"] = True

        if urls := request.input_reference:
            # 不支持参考图
            # payload["ReferenceImages"] = [
            #     {
            #         "BucketName": "ark-common-storage-prod-cn-beijing",
            #         "ObjectKey": f"presets/experience/gen_video/materials/自定义/{i}",
            #         "Url": url,
            #         "Label": f"image_{i}_{i}"
            #     }
            #     for i, url in enumerate(urls, 1)
            # ]
            urls = await upload(urls, api_key=api_key)

            if len(urls) == 1:
                payload["VideoTaskType"] = "first_frame"
                payload["FirstFrameImageTosLocation"] = urls[0]
            elif len(urls) >= 2:
                payload["VideoTaskType"] = "first_last_frame"
                payload["FirstFrameImageTosLocation"] = urls[0]
                payload["LastFrameImageTosLocation"] = urls[1]

        if request.first_frame_image:
            payload["VideoTaskType"] = "first_frame"
            payload["FirstFrameImageTosLocation"] = await upload(request.first_frame_image, api_key=api_key)

        if request.last_frame_image:
            payload["VideoTaskType"] = "first_last_frame"
            payload["LastFrameImageTosLocation"] = await upload(request.last_frame_image, api_key=api_key)

        logger.debug(bjson(payload))

        response = await self.client.post("/CreateVideoGenTask", body=payload, cast_to=object)
        logger.debug(bjson(response))
        """
        {'ResponseMetadata': {'Action': 'CreateVideoGenTask',
                      'Duration': 448,
                      'Error': {'Code': 'CreateExperienceVisionTaskFailed',
                                'CodeN': 1009000,
                                'Message': '{"error":{"code":"InvalidParameter","message":"The '
                                           'parameter '
                                           '`execution_expires_after` '
                                           'specified in the request is not '
                                           'valid: the specified '
                                           'execution_expires_after 345600 '
                                           'does not support content '
                                           'generation. Request id: '
                                           '0217708948167874d1a7bd4cdfcf1811296cf68db8d43d8aa0100","param":"execution_expires_after","type":"BadRequest"}}'},
                      'Region': 'cn-beijing',
                      'RequestId': '202602121913367C8697C6C18BB919E2FD',
                      'Service': 'ark',
                      'Version': '2024-01-29'},
 'Result': None}
 
 {'ResponseMetadata': {'Action': 'CreateVideoGenTask',
                      'Duration': 629,
                      'Region': 'cn-beijing',
                      'RequestId': '202602121916218D56A5423FB9761137C0',
                      'Service': 'ark',
                      'Version': '2024-01-29'},
 'Result': {'Id': 'cgt-20260212191621-b9l7b'}}
        """
        if task_id := (response.get("Result") or {}).get("Id"):
            if "seedance" not in request.model:
                task_id = f"{request.model}::{task_id}"

                payload['Ratio'] = "720p"
                if "veo" in request.model:
                    payload['Duration'] = 8

                elif "sora" in request.model:  # sora-2-4s sora-2-8s sora-2-12s sora-2-15s
                    if request.model.endswith('s'):  # 逆向
                        payload['Duration'] = int(request.model.split('-')[-1].replace("s", ""))
                    elif request.model == "sora-2":  # 逆向
                        payload['Duration'] = 15

            video = Video(id=task_id)
            return video

        elif e := response.get("ResponseMetadata", {}).get("Error"):
            error = {
                "code": e.get("Code", "400"),
                "message": e.get("Message", str(e))
            }
            if "QuotaExceeded" in str(e):  # 切备用渠道
                error = "未知错误，请重试"
                raise ValueError(error)

            video = Video(status="failed", error=error)

            return video

    async def get(self, task_id: str):
        transfer = False
        if "::" in task_id:
            task_id = task_id.split("::")[-1]
            transfer = True

        response = await self.client.post("/GetVideoGenTask", body={"Id": task_id}, cast_to=object)
        # logger.debug(bjson(response))

        if url := (response.get("Result") or {}).get("VideoUrl"):
            logger.debug(bjson(response))

            if transfer:
                url = await to_url(url, filename=f'{shortuuid.random()}.mp4')  # 避免重复转存

            return Video(id=task_id, video_url=url, status="completed", progress=100)
        else:
            return Video(id=task_id)


# 执行异步函数
if __name__ == "__main__":
    api_key = """ve_doc_history=82379%2C6269%2C6256%2C85128%2C86081%2C6348%2C85621%2C6260;_qimei_fingerprint=dd38b822c43601e30b795b0bb06bc28b;hasUserBehavior=1;monitor_huoshan_web_id=7467761534115284489;referrer_title=%E5%88%9B%E5%BB%BA%E8%A7%86%E9%A2%91%E7%94%9F%E6%88%90%E4%BB%BB%E5%8A%A1%20API--%E7%81%AB%E5%B1%B1%E6%96%B9%E8%88%9F%E5%A4%A7%E6%A8%A1%E5%9E%8B%E6%9C%8D%E5%8A%A1%E5%B9%B3%E5%8F%B0-%E7%81%AB%E5%B1%B1%E5%BC%95%E6%93%8E;AccountID=2104716667;user_locale=zh;signin_i18next=zh;monitor_session_id_flag=1;monitor_traceid_base_cookie=1418;volcengineLoginMethod=pwd;_tea_utm_cache_3569={%22utm_source%22:%22coopensrc%22%2C%22utm_medium%22:%22github%22%2C%22utm_campaign%22:%22doubao%22%2C%22utm_term%22:%22project%22%2C%22utm_content%22:%22aidrawio%22};volcfe-uuid=0701f6f2-a611-4599-a2fc-57cb015ff828;userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjEwNDcxNjY2NywiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczNDc3MzIxLCJpIjoiYzUxNTFmMzUwN2VkMTFmMTllYTUzNDM2YWMxMjAwYzciLCJpZF9uIjoiODQzMuaJi-acuueUqOaItyNaY1JzUnkiLCJtc2ciOm51bGwsInBpZCI6IjBkMDQ2ZDlkLTg4NTYtNDhiNy1iZGMzLWQ0OTI4ODQ3Njc2YiIsInNzX24iOiI4NDMy5omL5py655So5oi3I1pjUnNSeSIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.gfVFCXMedtkYoGFpObMWKulX5QPrdSDadKKyxMl7TecUX4gxF53E4NaZjMfDruLDu7gIlIEhbLyUzMvOJtUFyVtP1VIZDXD1zOLf7T-nKO4WH4MEEHf6F-ERzjMabSQfotnaEeMyysjbetQJ38UEA6hF_C70zo-hv_sIKdMVMTqLt2J7Sf1ry0qNDGEMBQzOB6hNB5amF6NB9GByLZEl-RjovAbB3SkarTSpWLnekrUxyJXD-SIdN80kKOrnlugyMFCE_NPVuZ4ZFgTyKJt1o0Yp_-jb1GBJDUeY2Tq-vDjalIvT9q-PJE4MCw9Bb4VIkaVFfobO1sDiOocvu00gTg;__tea_cache_tokens_3569={%22web_id%22:%227467761534115284489%22%2C%22user_unique_id%22:%227467761534115284489%22%2C%22timestamp%22:1770885409545%2C%22_type_%22:%22default%22};volc-design-locale=zh;_qimei_h38=47aeffd76da9e4a25cf291fa0300000d619a11;finance-hub-sdk-lang=zh;p_c_check=1;volc_platform_clear_user_locale=1;__spti=11_000JnXNrWATPtPrMwlQ3ilQxfn2UtC;__sptiho=0B11_000JnXNrWATPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC;_qimei_i_1=5ac22586920b058d97c3f9360fd57ab5f3bfa6f4410d018bb5d979582593206c616363933980b3ddd790cf8f;_qimei_i_3=57ca79d3970c52d9c497aa625d8027e5a6bcf0f71a5b04d4e0872b502092276d32633f973989e28184b1;_qimei_uuid42=19c180a1723100cab20e31b701a4124555c551b916;_tea_utm_cache_520918={%22utm_source%22:%22coopensrc%22%2C%22utm_medium%22:%22github%22%2C%22utm_campaign%22:%22doubao%22%2C%22utm_term%22:%22project%22%2C%22utm_content%22:%22aidrawio%22};csrfToken=b6b2764fc8bf2869340ddeaa2d5b81ac;digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzEwNTgxMjEsImlhdCI6MTc3MDg4NTMyMSwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiIwZDA0NmQ5ZC04ODU2LTQ4YjctYmRjMy1kNDkyODg0NzY3NmIiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpRd01UYzBNek16bHppMGNOc1pOb1dUSUZMSW40dmRNVGs1dnpTdlJPRDNyYk92MmFYRUxVeU1qWjUxZGorYnMrdjVsQlhQT3JZclJ5VUhGUWRWS29ITjBXSkx6cy9OemMvendxVU1FQUFBLy8vSzNjZTVjUUFBQUE9PSIsIm5hbWUiOiI4NDMy5omL5py655So5oi3I1pjUnNSeSIsInN1YiI6IjIxMDQ3MTY2NjciLCJ0b3BpYyI6InNpZ25pbl9jcmVkZW50aWFsIiwidHJuIjoidHJuOmlhbTo6MjEwNDcxNjY2Nzpyb290IiwidmVyc2lvbiI6InYxIiwiemlwIjoiZ3ppcCJ9.Z-eEz3F4-7zEBTycZtzF2L0DjTnNMvmWMai7yfbsbK4VAvzlw8l0XJ4qxzch9RcIZKvK_Hp_iKzitotsFQHQHhmElcF1l5X3CgGhB4bM4DHKbvU1Q8rwn2IqMZeVjPnVcaA9U6G9nCCYtmgdWfiilPO3EyC7Wirx7TBhRkW2IcFtZhO_Ft5IN25A7TVWioaWuRTqAlKUsFujENgx23uQ2VPhKx6q8_vp4vbmRC-vshFM2osYq-3o_shi3bKS-S-eZjLdOKqfRlY5qsf_SBDpv08yXVIntzGlHKAO1jzrBxwDRQZp5aDv4J6RYtoJKsyE9-ISbrb_p3BD4h2kbuIHQA;gfkadpd=520918,36088|3569,42874;i18next=zh;isIntranet=0;login_scene=11;monitor_session_id=0137731691764811011;monitor_utm=%257B%2522utm_campaign%2522%253A%2522doubao%2522%252C%2522utm_content%2522%253A%2522aidrawio%2522%252C%2522utm_medium%2522%253A%2522github%2522%252C%2522utm_source%2522%253A%2522coopensrc%2522%252C%2522utm_term%2522%253A%2522project%2522%257D;s_v_web_id=verify_mjjfj194_6wx9uxHT_RbvK_42dT_BQQF_Am4VHcR3e6qJ;top_region=;vcloudWebId=0d8e34f9-2a27-4f3b-a86a-10cb562dbf67;VOLCFE_im_uuid=1770641165069598896"""

    api_key = """ve_doc_history=82379%2C6269%2C6256%2C85128%2C86081%2C6348%2C85621%2C6260;_qimei_fingerprint=dd38b822c43601e30b795b0bb06bc28b;hasUserBehavior=1;monitor_huoshan_web_id=7467761534115284489;referrer_title=%E5%88%9B%E5%BB%BA%E8%A7%86%E9%A2%91%E7%94%9F%E6%88%90%E4%BB%BB%E5%8A%A1%20API--%E7%81%AB%E5%B1%B1%E6%96%B9%E8%88%9F%E5%A4%A7%E6%A8%A1%E5%9E%8B%E6%9C%8D%E5%8A%A1%E5%B9%B3%E5%8F%B0-%E7%81%AB%E5%B1%B1%E5%BC%95%E6%93%8E;AccountID=2109091919;user_locale=zh;signin_i18next=zh;monitor_session_id_flag=1;monitor_traceid_base_cookie=1419;volcengineLoginMethod=pwd;_tea_utm_cache_3569={%22utm_source%22:%22coopensrc%22%2C%22utm_medium%22:%22github%22%2C%22utm_campaign%22:%22doubao%22%2C%22utm_term%22:%22project%22%2C%22utm_content%22:%22aidrawio%22};volcfe-uuid=0701f6f2-a611-4599-a2fc-57cb015ff828;userInfo=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5YzBkZmFjYmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhY2NfaSI6MjEwOTA5MTkxOSwiYXVkIjpbImNvbnNvbGUudm9sY2VuZ2luZS5jb20iXSwiZXhwIjoxNzczNDk5Mzk0LCJpIjoiMjk2OTc3MmEwODIxMTFmMTlhZjEzNDM2YWMxMjAwM2YiLCJpZF9uIjoiMDQzNeaJi-acuueUqOaItyN5SFNrTXQiLCJtc2ciOm51bGwsInBpZCI6ImNkNDlmYTg3LWI3NzUtNDQwNS1iOTkzLTVmOTA0NTMyNDg5MSIsInNzX24iOiIwNDM15omL5py655So5oi3I3lIU2tNdCIsInQiOiJBY2NvdW50IiwidG9waWMiOiJzaWduaW5fdXNlcl9pbmZvIiwidmVyc2lvbiI6InYxIiwiemlwIjoiIn0.cdpiB9xgcokJBJzG-S_BIdllMusycBqNLL8VNEnmlFI5i0fYstJUbAvLC-nbouHZjLhX9XzT45RjIqbFa-f1dnQHE6SmMf_CCPuxoZOpd7UnJTbCqQiKO_KRkdshxpuIxx7mV74ziS3UQWcNARIH663BxmsMsPWFx7Tntx3QOCdu_zljgJkjbxJZhcBhGOqGC2CMZXocr0MorPpcEVtXPOsRi9ulCBMSSH4kI5z4iigbliLyoYcsD3vNCmGO_vTOPDAdyEwGE395FwAnlB62JGnwVAreHvdPLE3YFMBII2JdDT03TGOrb1VFP6tLj2xOAWCDlVJnxRkW2fDZ16d71Q;__tea_cache_tokens_3569={%22web_id%22:%227467761534115284489%22%2C%22user_unique_id%22:%227467761534115284489%22%2C%22timestamp%22:1770907429996%2C%22_type_%22:%22default%22};volc-design-locale=zh;_qimei_h38=94cee221b20e31b701a412450300000ce19c18;finance-hub-sdk-lang=zh;p_c_check=1;volc_platform_clear_user_locale=1;__spti=11_000JnXNrWATPtPrMwlQ3ilQxfn2UtC;__sptiho=0B11_000JnXNrWATPtPrMwlQ3ilQxfn2UtC_bEv/KoxCOM4AcC;_qimei_i_1=5eea2c8b9109058ec395ff62598426e3f6bca3f1130a0783b68b2d582593206c616364c03980b1ddde92f7cc;_qimei_i_3=57ca79d3970c52d9c497aa625d8027e5a6bcf0f71a5b04d4e0872b502092276d32633f973989e28184b1;_qimei_uuid42=19c180a1723100cab20e31b701a4124555c551b916;_tea_utm_cache_520918={%22utm_source%22:%22coopensrc%22%2C%22utm_medium%22:%22github%22%2C%22utm_campaign%22:%22doubao%22%2C%22utm_term%22:%22project%22%2C%22utm_content%22:%22aidrawio%22};csrfToken=499beb4542dac5d353afbb1fffd981eb;digest=eyJhbGciOiJSUzI1NiIsImtpZCI6ImE5ZDM1YTQ4YmZiNDExZjA4OWMwMDAxNjNlMDcwOGJkIn0.eyJhdWQiOlsiY29uc29sZS52b2xjZW5naW5lLmNvbSJdLCJleHAiOjE3NzEwODAxOTQsImlhdCI6MTc3MDkwNzM5NCwiaXNzIjoiaHR0cHM6Ly9zaWduaW4udm9sY2VuZ2luZS5jb20iLCJqdGkiOiJjZDQ5ZmE4Ny1iNzc1LTQ0MDUtYjk5My01ZjkwNDUzMjQ4OTEiLCJtc2ciOiJINHNJQUFBQUFBQUMvK0tTNDJMeFM4eE5GZUl5TWpTd05MQTB0RFMwbFBoNWR2c1pOb1dtYzl2UHNBbjVjN0U3SmlmbmwrYVZDSngvY09NdHU1UzRnWW14NmJQTzdtZHpkajJmc3VKWngzYmxTby9nYk44U0piQTVXbXpKK2JtNStYbGV1SlFCQWdBQS8vOTdrMG13Y1FBQUFBPT0iLCJuYW1lIjoiMDQzNeaJi-acuueUqOaItyN5SFNrTXQiLCJzdWIiOiIyMTA5MDkxOTE5IiwidG9waWMiOiJzaWduaW5fY3JlZGVudGlhbCIsInRybiI6InRybjppYW06OjIxMDkwOTE5MTk6cm9vdCIsInZlcnNpb24iOiJ2MSIsInppcCI6Imd6aXAifQ.fw4LobnAByUwIaCOWhOOvF5igRzIo_l5lBme2SmfeT5vwky01EI2iBDBayuv_O39Uvl-MzS5Gmg2-tXFN7tqEyH2ERa1ymuZETFkFu3P-su9Uqb1VZnFpkaZsjHzhCTWIxvwDLmBCZM0aLN_LOBjhDyoRjd6agYr8XLrTM3UzVRb-MUg_yYBBSttvUpZdM4pLQ3magTu0xJQY0OfLg4IBTezfg84XsQJkh0wGaJI1N-_aXTTXTFBOBahMS8fKJrNG-mgV52xMxBqS_pt3piGwn3ssMVeD5JD5K474FMKxIhgwJUkdePfsVACAjBhaLmV6AmYX4UXo7lTmjHHIZnp3Q;gfkadpd=520918,36088|3569,42874;i18next=zh;isIntranet=0;login_scene=11;monitor_session_id=0008375069127979375;monitor_tracing_cookie=[];monitor_utm=%257B%2522utm_campaign%2522%253A%2522doubao%2522%252C%2522utm_content%2522%253A%2522aidrawio%2522%252C%2522utm_medium%2522%253A%2522github%2522%252C%2522utm_source%2522%253A%2522coopensrc%2522%252C%2522utm_term%2522%253A%2522project%2522%257D;s_v_web_id=verify_mjjfj194_6wx9uxHT_RbvK_42dT_BQQF_Am4VHcR3e6qJ;top_region=;vcloudWebId=0d8e34f9-2a27-4f3b-a86a-10cb562dbf67;VOLCFE_im_uuid=1770641165069598896"""
    request = SoraVideoRequest(
        # prompt="【图片 1】【图片 2】融合起",
        prompt="孙悟空",

        # seconds=4,
        # resolution="480p",

        seconds=15,
        resolution="720p",
        # aspect_ratio="adaptive",
        # input_reference=[
        #     "https://storage.googleapis.com/falserverless/example_inputs/nano-banana-edit-input.png",
        #     "https://storage.googleapis.com/falserverless/example_inputs/nano-banana-edit-input-2.png"
        # ]

        # first_frame_image="https://storage.googleapis.com/falserverless/example_inputs/nano-banana-edit-input.png",
        # last_frame_image="https://storage.googleapis.com/falserverless/example_inputs/nano-banana-edit-input-2.png"

    )
    task_ids = []
    # for i in range(120):
    #     request.prompt = f"孙悟空大声叫 {i}"
    #     video = arun(Tasks(api_key).create(request))
    #     task_ids.append(video.id)

    # arun(Tasks(api_key).create(request))
    # # task_id = "cgt-20260212191621-b9l7b"
    # # task_id = "cgt-20260212193527-b7xll"
    # # task_id = "cgt-20260212194710-gwzpn"
    # # task_id = "cgt-20260212200601-474df" # 首尾帧
    # task_id = "cgt-20260212202542-mjzbb"
    task_id = "sora-2::cgt-20260212224451-6nrdn"
    arun(Tasks(api_key).get(task_id))

    t = ['cgt-20260212202400-zrkm4',
         'cgt-20260212202401-8ppjx',
         'cgt-20260212202402-4s2lq',
         'cgt-20260212202403-vd9mh',
         'cgt-20260212202404-czg7k',
         'cgt-20260212202405-tmd9k',
         'cgt-20260212202406-frjnv',
         'cgt-20260212202407-ml7zz',
         'cgt-20260212202407-4j6ws',
         'cgt-20260212202409-9znbd',
         'cgt-20260212202410-fll8p',
         'cgt-20260212202411-6jbp9',
         'cgt-20260212202412-l464s',
         'cgt-20260212202413-8vkkg',
         'cgt-20260212202413-j2m4q',
         'cgt-20260212202414-rs7wz',
         'cgt-20260212202415-s642l',
         'cgt-20260212202416-9jj9p',
         'cgt-20260212202417-qnb6z',
         'cgt-20260212202417-2gb8f',
         'cgt-20260212202418-7l9kr',
         'cgt-20260212202419-wfmpf',
         'cgt-20260212202420-j9pqw',
         'cgt-20260212202421-h7fj9',
         'cgt-20260212202422-lfvgw',
         'cgt-20260212202422-xfs4c',
         'cgt-20260212202423-66krj',
         'cgt-20260212202424-qvbzd',
         'cgt-20260212202425-b9nns',
         'cgt-20260212202426-pwhlq',
         'cgt-20260212202427-rjmwn',
         'cgt-20260212202427-q9gjw',
         'cgt-20260212202428-m2gsg',
         'cgt-20260212202429-9z8c7',
         'cgt-20260212202430-6dx2l',
         'cgt-20260212202431-mjgpl',
         'cgt-20260212202432-lgxnb',
         'cgt-20260212202432-6f4pb',
         'cgt-20260212202433-b8chd',
         'cgt-20260212202434-5647k',
         'cgt-20260212202435-4prdm',
         'cgt-20260212202436-99rcw',
         'cgt-20260212202437-ztlzw',
         'cgt-20260212202437-dkvbh',
         'cgt-20260212202438-k64sd',
         'cgt-20260212202439-lq4km',
         'cgt-20260212202440-jf7m4',
         'cgt-20260212202441-2tb8c',
         'cgt-20260212202442-j55nz',
         'cgt-20260212202442-qjqlh',
         'cgt-20260212202443-rtdl5',
         'cgt-20260212202444-4wrcf',
         'cgt-20260212202445-hsxdp',
         'cgt-20260212202446-z2k2z',
         'cgt-20260212202447-7cb6f',
         'cgt-20260212202448-ld76h',
         'cgt-20260212202448-vp4k6',
         'cgt-20260212202449-xlgcf',
         'cgt-20260212202450-qcczc',
         'cgt-20260212202451-qfdzg',
         'cgt-20260212202452-xbpvf',
         'cgt-20260212202453-bzv7s',
         'cgt-20260212202454-rn9n7',
         'cgt-20260212202454-jv4gs',
         'cgt-20260212202455-28wl2',
         'cgt-20260212202456-rhnq8',
         'cgt-20260212202457-hrqsb',
         'cgt-20260212202458-4mdns',
         'cgt-20260212202459-mmm89',
         'cgt-20260212202459-27rmp',
         'cgt-20260212202500-mvn7v',
         'cgt-20260212202501-hbgfs',
         'cgt-20260212202502-kvvf8',
         'cgt-20260212202503-s5qjm',
         'cgt-20260212202504-p4kkd',
         'cgt-20260212202504-94cfr',
         'cgt-20260212202505-8nj6p',
         'cgt-20260212202506-h6zr4',
         'cgt-20260212202507-n9vm6',
         'cgt-20260212202507-w6hh5',
         'cgt-20260212202508-xtqg7',
         'cgt-20260212202509-tp5p6',
         'cgt-20260212202510-9ls7l',
         'cgt-20260212202511-mfwct',
         'cgt-20260212202512-7lnrs',
         'cgt-20260212202513-q84ss',
         'cgt-20260212202514-rgpmq',
         'cgt-20260212202514-nng8d',
         'cgt-20260212202515-rsmgq',
         'cgt-20260212202516-c8th4',
         'cgt-20260212202517-g694z',
         'cgt-20260212202518-kj8bl',
         'cgt-20260212202519-nf82w',
         'cgt-20260212202520-vslgd',
         'cgt-20260212202521-lsvgp',
         'cgt-20260212202521-6g6ps',
         'cgt-20260212202522-mrhpf',
         'cgt-20260212202523-hvn48',
         'cgt-20260212202524-h2pqp',
         'cgt-20260212202525-67z4s',
         'cgt-20260212202526-z2tng',
         'cgt-20260212202527-sdrfp',
         'cgt-20260212202527-c9w7q',
         'cgt-20260212202528-2frs4',
         'cgt-20260212202529-fdl4z',
         'cgt-20260212202530-4sg92',
         'cgt-20260212202531-cpq9z',
         'cgt-20260212202532-hg448',
         'cgt-20260212202532-cbx92',
         'cgt-20260212202533-nsrpf',
         'cgt-20260212202534-blpk9',
         'cgt-20260212202535-hj2rj',
         'cgt-20260212202536-nrvpb',
         'cgt-20260212202537-9glbk',
         'cgt-20260212202538-8qldz',
         'cgt-20260212202538-dv6r5',
         'cgt-20260212202539-j2s2z',
         'cgt-20260212202540-pkwrj',
         'cgt-20260212202541-8tnd8',
         'cgt-20260212202542-mjzbb']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : demo
# @Time         : 2021/4/2 3:54 下午
# @Author       : yuanjie
# @WeChat       : 313303303
# @Software     : PyCharm
# @Description  : 
import asyncio
import traceback
from typing import Optional, Callable
from contextlib import asynccontextmanager, contextmanager

from meutils.notice.feishu import send_message_for_try_catch


@asynccontextmanager
async def atry_catch(
        task: Optional[str] = None,
        callback: Optional[Callable] = None,
        is_trace: bool = False,
):
    callback = callback or send_message_for_try_catch

    task_name = task or "Unnamed TryCatch Task"

    data = {
        "task_name": task_name,
    }

    # logger.debug(data)

    try:
        yield
    except Exception as e:
        if is_trace:
            error_msg = f"""{task_name}:\n{traceback.format_exc()}"""
        else:
            error_msg = f"{task_name}: {e}"

        data["error"] = error_msg

        callback(data)
        raise


@contextmanager
def try_catch(
        task: Optional[str] = None,
        callback: Optional[Callable] = None,
        is_trace: bool = False,
):
    callback = callback or send_message_for_try_catch

    task_name = task or "Unnamed TryCatch Task"

    data = {
        "task_name": task_name,
    }

    # logger.debug(data)

    try:
        yield
    except Exception as e:
        if is_trace:
            error_msg = f"""{task_name}:\n{traceback.format_exc()}"""
        else:
            error_msg = f"{task_name}: {e}"

        data["error"] = error_msg

        callback(data)
        raise


if __name__ == '__main__':
    from meutils.pipe import *


    async def f():
        return 1


    async def main():
        # with atry_catch_context(task="test", is_trace=True):
        #     1 / 0
        with try_catch(task="test", is_trace=True):
            logger.debug(await f())
            1 / 0


    asyncio.run(main())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : videos
# @Time         : 2026/1/29 14:37
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : todo 基础 继承
import os

from meutils.pipe import *
from meutils.schemas.video_types import SoraVideoRequest, Video

from openai import AsyncOpenAI
from openai import APIError

"""https://aiping.cn/docs/API/VideoAPI/KLING_VIDEO_API_DOC
o1

文生视频
图生视频（首尾帧）
图片/主体参考生成视频
视频编辑（指令变换）
视频风格/运镜参考
视频延长（生成下一个/上一个镜头）

动作控制 API 支持通过参考图像和参考视频生成动作控制视频，生成视频中的人物动作与参考视频一致。



目前kling-video-o1正确的示例是这样的👇

curl -X 'https://www.aiping.cn/api/v1/videos' \
--header 'Authorization: Bearer xxx' \
--header 'Content-Type: application/json' \
--data '{
            "model": "Kling-Video-O1",
            "prompt": "参考<<<video_1>>>的运镜方式，生成一段视频：<<<element_1>>>和<<<element_2>>>在东京街头漫步，偶遇<<<image_1>>>",
            "reference_images": [
               "http://wanx.alicdn.com/material/20250318/stylization_all_1.jpeg"
            ],
            "element_list": [
                {
                    "element_id": "146"
                },
                {
                    "element_id": "145"
                }
            ],
            "video_list": [
                {
                    "video_url": "https://cdn.wanx.aliyuncs.com/static/demo-wan26/vace.mp4",
                    "refer_type": "feature",
                    "keep_original_sound": "yes"
                }
            ],
            "mode": "pro",
            "aspect_ratio": "1:1",
            "duration": "7"
        }'
"""

BASE_URL = "https://aiping.cn/api/v1"


class Tasks(object):

    def __init__(self, base_url: Optional[str] = None, api_key: Optional[str] = None):
        self.api_key = api_key or os.getenv("AIPING_API_KEY")
        self.client = AsyncOpenAI(api_key=self.api_key, base_url=BASE_URL)

    async def create(self, request: SoraVideoRequest):  # todo 区分模型
        payload = {
            "model": request.model,
            "prompt": request.prompt,
            "seconds": request.seconds,
        }

        if request.model.endswith("-pro"):
            payload["mode"] = "pro"
            payload["model"] = payload["model"].strip("-pro")
        elif request.model.endswith("-std"):
            payload["mode"] = "std"
            payload["model"] = payload["model"].strip("-std")

        for param in ["aspect_ratio", "action_control", "callback_url", "character_orientation"]:
            if hasattr(request, param) and getattr(request, param) is not None:
                payload[param] = getattr(request, param)

        if urls := request.input_reference:
            payload['image_url'] = urls[0]  # 845850588004376646_437103
            payload['reference_images'] = urls

        if url := request.first_frame_image:
            payload['first_frame_url'] = url

        if url := request.last_frame_image:
            payload['last_frame_url'] = url

        if url := request.image:
            payload["image_url"] = url

        if url := request.video:
            payload['video_url'] = url

        logger.debug(bjson(payload))

        try:

            response = await self.client.post(path="/videos", body=payload, cast_to=object)
            logger.debug(response)
            """
            {'id': '845809073383034963_437103', 'status': 'queued', 'created_at': '2026-01-29T11:11:56.304273Z', 'model': 'Kling-Video-O1', 'provider': '可灵AI'}
            
            openai.InternalServerError: Error code: 500 - {'detail': {'message': "ERROR: Provider 可灵AI returned status 400: {'code': 1201, 'message': 'Aspect ratio must be specified when no first image and not video editing', 'request_id': '9d490e21-b381-4b26-a071-f04afd83efb8'} (status=400)", 'error_type': 'internal_error'}}
            """
            if isinstance(response, dict) and (task_id := response.get("id")):
                response.pop("created_at", None)
                return Video(**response)

        except APIError as e:
            error = {
                'code': e.code, 'message': e.message
            }
            # return Video(status="failed", error=error)
            raise e

    async def get(self, task_id: str, ):
        response = await self.client.get(path=f"/videos/{task_id}", cast_to=object)
        logger.debug(bjson(response))
        if response.get("status") == "completed":
            response.pop("created_at", None)
            response.pop("completed_at", None)

            return Video(**response)

        """
        {
    "id": "845809073383034963_437103",
    "status": "completed",
    "created_at": "2026-01-29T11:11:56.000000Z",
    "model": "Kling-Video-O1",
    "completed_at": "2026-01-29T11:17:12.746607Z",
    "updated_at": "2026-01-29T11:17:12.746607Z",
    "video_url": "https://v4-fdl.kechuangai.com/ksc2/pNKqHLkicA7peTCVLqaCxKvdsGNOBvxTnPaNWI9B6jufiqlFt2WiyAlMSd5NtBIa0ltAD74tDG9kdlxYasJxoOUBjwZzBjiHNw5x45ryioAHK3gLZxA2I-THacdKLOaPx2nLXZhRW4bXz4wjd6B-ZNFchWoR6flf85Kll44wAPoai5x4zk3sRFzEIs4KafgcMSWIhWOg-2vx4AP2SmToHQ.mp4?cacheKey=ChtzZWN1cml0eS5rbGluZy5tZXRhX2VuY3J5cHQSsAGGLL3aBUGCX5e0UqY87UWl6t4SFbxKr5xtoA6iRap5mQRIGvAZNb_t0O8xMlBLYtt-3drDYWmmABJyD8m8jE1pQ_zatvsYkEPZXxWhXXi48QrXbQwqtCNhuVOyMiiBtSwdDaq_a1a9k6WToopVBEyoKGazRM_ls38pt7yrBnwka2nvbkdiUknhuxXlul5y0RT6w-JzOwMVTiffkeZe1zGm2v5rxn1vd8OVRqGvAhqBrhoSK9DDR3Zts0AO39BBzVqoebvyIiDqaVNmCGa6E5OcURU5sWKA7aHrUnblB0T7_qwLc6_RSigFMAE&x-kcdn-pid=112757&pkey=AAUPAfYdTaZ0RM3N37CbkD6NjOFIU0Va0gh0erjEo6oMxbjhUNt58DFTsqMR0QqyElhUJ2V0RPvRidOboyAZQdUXih3gzOMwIgzS5NtgYG-CSytBbjPduh5EsU03Z5KIiIU",
    "raw_response": {
        "code": 0,
        "message": "SUCCEED",
        "request_id": "db60eb9b-a00c-4e90-8e98-a5e881939d16",
        "data": {
            "task_id": "845809073383034963",
            "task_status": "succeed",
            "task_info": {},
            "task_result": {
                "videos": [
                    {
                        "id": "845809073525633087",
                        "url": "https://v4-fdl.kechuangai.com/ksc2/pNKqHLkicA7peTCVLqaCxKvdsGNOBvxTnPaNWI9B6jufiqlFt2WiyAlMSd5NtBIa0ltAD74tDG9kdlxYasJxoOUBjwZzBjiHNw5x45ryioAHK3gLZxA2I-THacdKLOaPx2nLXZhRW4bXz4wjd6B-ZNFchWoR6flf85Kll44wAPoai5x4zk3sRFzEIs4KafgcMSWIhWOg-2vx4AP2SmToHQ.mp4?cacheKey=ChtzZWN1cml0eS5rbGluZy5tZXRhX2VuY3J5cHQSsAGGLL3aBUGCX5e0UqY87UWl6t4SFbxKr5xtoA6iRap5mQRIGvAZNb_t0O8xMlBLYtt-3drDYWmmABJyD8m8jE1pQ_zatvsYkEPZXxWhXXi48QrXbQwqtCNhuVOyMiiBtSwdDaq_a1a9k6WToopVBEyoKGazRM_ls38pt7yrBnwka2nvbkdiUknhuxXlul5y0RT6w-JzOwMVTiffkeZe1zGm2v5rxn1vd8OVRqGvAhqBrhoSK9DDR3Zts0AO39BBzVqoebvyIiDqaVNmCGa6E5OcURU5sWKA7aHrUnblB0T7_qwLc6_RSigFMAE&x-kcdn-pid=112757&pkey=AAUPAfYdTaZ0RM3N37CbkD6NjOFIU0Va0gh0erjEo6oMxbjhUNt58DFTsqMR0QqyElhUJ2V0RPvRidOboyAZQdUXih3gzOMwIgzS5NtgYG-CSytBbjPduh5EsU03Z5KIiIU",
                        "duration": "5.041"
                    }
                ]
            },
            "task_status_msg": "",
            "created_at": 1769685116248,
            "updated_at": 1769685162155,
            "final_unit_deduction": "4"
        }
    },
    "usage": {
        "seconds": 5.041,
        "video_count": 1
    }
}
        """


if __name__ == '__main__':
    api_key = "QC-26c8f1bf2f34ced0079651def44a5e84-1023520e28cbc06c1a54eb1a85ae2200"  # os.getenv("AIPING_API_KEY")

    model = "Kling-Video-O1"  # 845851366781628485_437103
    # 3-10，文生视频仅支持 5 和 10

    request = SoraVideoRequest(
        model=model,
        prompt="让花被风吹动",
        seconds=5,
        aspect_ratio="9:16",
        # first_frame_image="http://wanx.alicdn.com/material/20250318/stylization_all_1.jpeg",
        input_reference=["http://wanx.alicdn.com/material/20250318/stylization_all_1.jpeg"],

        # prompt="视频中女生用图片中人物的动作",
        # action_control=True,
        # character_orientation="image",
        # image="https://help-static-aliyun-doc.aliyuncs.com/file-manage-files/zh-CN/20250925/wpimhv/rap.png",
        # video="https://v4-fdl.kechuangai.com/ksc2/WDy7TzddQesPc-yzgBHGLPC-DvJ1-H7xTMOmXwQyWLqad7vNOco9rc4aaG2TUWYGqLjRbIfafrJKn4BKLbkawwZsP7XbXQjyZejDDnV72jn7_uOKClcPl_3iIfXtHjik6qPjvmUX8BMCVAJu-9SnQfKNe24uiR78liroaGqRYtK-N_fG73vxHzRKCzkLlGT7No6T2cwFXwB-N25EbGzEnA.mp4?cacheKey=ChtzZWN1cml0eS5rbGluZy5tZXRhX2VuY3J5cHQSsAEma1yqW3VkomHRW0QCf5HwtoGt1rsP1BfAaMCMvDUwUAQgKlNOKcqrRXahLmKVhnsgoDAIr_8ClW7Alw0lH5jlAnCMEDaevpHviFPuz_l2o1AiF-2MAuH85g_3pxisF25afS-VkzHeF345qaxRQpXl9svOZ5KJY-iGnO2MZsk8d5sq-T8BgaiacFbWhYGDsAGIl6cUtyKhje6Q0iavjLp2FWU6qRBNpxQMr5y-flEUVRoS09j_LL38Qv8Yv5Zh0thEYW8BIiBztCBY7m6iJP0Ol_qpaQSK1zVVBP52cd9VUG0X30dhHygFMAE&x-kcdn-pid=112757&pkey=AAVML7K6rCyYzbp4euU3NAb4liSq8HDEALE2jL_AqZqjp8ylQaYSG0AWd4-sSxFiQXblYdsfN46p1KRhcn1JfQLKTL30VMioea-RzCILZQ_lHHOkDkLQwT2MfkktWUeLDSA"
    )

    t = Tasks(api_key=api_key)
    # arun(t.create(request))
    #
    # arun(t.get("845850588004376646_437103"))
    # task_id = "845852484547010604_437103"
    task_id = "845857300375576633_437103"
    arun(t.get(task_id))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : kolors
# @Time         : 2024/7/10 13:13
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://kolors.kuaishou.com/


import jsonpath

from meutils.pipe import *
from meutils.decorators.retry import retrying
from meutils.schemas.kuaishou_types import KolorsRequest
from meutils.notice.feishu import send_message as _send_message
from meutils.config_utils.lark_utils import get_next_token_for_polling

BASE_URL = "https://kolors.kuaishou.com"
OSS_URL = "https://s2-111386.kwimgs.com/bs2/mmu-kolors-public"
# https://s2-111386.kwimgs.com/bs2/mmu-kolors-public/5f9c7b42688fe95c4b8d9ebd1dba3431.png?x-oss-process=image/resize,m_mfit,w_305
# https://s2-111386.kwimgs.com/bs2/mmu-kolors-public/mmu-kolors-4243501072-1720596454510-1a862f8dbde042349b97445fc45ec231 # upload

FEISHU_URL = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=I9NCss"

send_message = partial(
    _send_message,
    title=__name__,
    url="https://open.feishu.cn/open-apis/bot/v2/hook/dc1eda96-348e-4cb5-9c7c-2d87d584ca18"
)


@retrying(predicate=lambda r: not isinstance(r, str))  # 触发重试
async def upload(file_or_url: Union[bytes, str], cookie: Optional[str] = None):  # todo: 垫图
    cookie = cookie or await get_next_token_for_polling(FEISHU_URL)

    headers = {
        'Cookie': cookie,
    }

    files = params = None
    if isinstance(file_or_url, bytes):
        files = [('file', file_or_url)]

    else:
        params = {
            'url': file_or_url
        }

    # files = [
    #     ('file', ('v的副本.jpg', open('/Users/betterme/Downloads/v的副本.jpg', 'rb'), 'image/jpeg'))
    # ]

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=100) as client:
        response = await client.post("/api/kolors/uploadToBlobStore", params=params, files=files)

        logger.debug(response.text)

        if response.is_success:
            data = response.json()
            send_message(data)

            try:
                rawKeys = jsonpath.jsonpath(data, "$..rawKey")
                if rawKeys:
                    url = f"{OSS_URL}/{rawKeys[0]}?x-oss-process=image/resize,m_mfit,w_1024"
                    return url

            except Exception as e:  # 429
                logger.error(e)

            else:
                return data


@retrying(max_retries=5, predicate=lambda r: not r)
async def create_task(request: KolorsRequest, cookie: Optional[str] = None):
    cookie = cookie or await get_next_token_for_polling(FEISHU_URL)

    headers = {
        'Cookie': cookie,
        'Content-Type': 'application/json;charset=UTF-8'
    }

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.post("/api/kolors/textToImage", json=request.model_dump())

        logger.debug(response.text)
        logger.info(response.status_code)

        if response.is_success:
            data = response.json()
            send_message(data)

            if data.get("code") == 500:
                return data  # 不重试
                # raise Exception(data)

            if any(i in str(data) for i in {"页面未找到", "请求超限"}):
                send_message(f"{data}\n\n{cookie}")
                return  # 404 429 重试

            # {"code":500,"result":{"status":"ERROR","code":33001,"reason":""}} 可能是内容审核的问题
            try:
                requestIds = jsonpath.jsonpath(data, "$..requestId")
                if requestIds:
                    logger.info(f"requestId or taskId: {requestIds[0]}")
                    response = await client.get("/api/kolors/queryAsyncTaskResult", params={"requestId": requestIds[0]})
                    logger.debug(response.text)

                    if response.is_success:
                        return requestIds[0]
                    else:
                        response.raise_for_status()

            except Exception as e:  # 429
                logger.error(e)

            else:
                return data


@retrying(max_retries=16, exp_base=1.1, min=2, predicate=lambda r: r == "RETRYING")  # 触发重试
async def get_task(task_id, cookie: str):
    headers = {
        'Cookie': cookie,
        'Content-Type': 'application/json;charset=UTF-8'
    }

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.get(f"/api/kolors/requests/{task_id}", params={"withWatermark": False})
        if response.is_success:
            data = response.json()

            logger.debug(data)

            if not task_id or "ERROR" in str(data): return "TASK_FAILED"  # 跳出条件

            urls = jsonpath.jsonpath(data, '$..imageBlobKey')
            if urls and all(urls):
                images = [{"url": f"{OSS_URL}/{url.replace('mmu:kolors-public:', '')}"} for url in urls]
                return images
            else:
                return "RETRYING"  # 重试


@retrying(max_retries=3, predicate=lambda r: r == "TASK_FAILED")
async def create_image(request: KolorsRequest, file: Optional[bytes] = None):
    cookie = await get_next_token_for_polling(FEISHU_URL)

    if file:
        request.referImage = await upload(file, cookie)

    logger.info(request)

    task_id = await create_task(request, cookie)
    logger.info(f"taskId: {task_id}")
    if isinstance(task_id, dict):
        return task_id

    data = await get_task(task_id, cookie)

    return data


if __name__ == '__main__':
    cookie = "kuaishou.dmo.ketu_ph=f711fb055f50eeb21fdb39bd6e05cc611744;kuaishou.dmo.ketu_st=ChRrdWFpc2hvdS5kbW8ua2V0dS5zdBKgAULU9RPZzOXOMUukfVPm51Ghgxee3d2ZFqxfGxQ4WRIWWbZ8omUKzDni1d_3R0s3hv9RfvRU7g0dW9v1lKXIMX23-ctLJ10YovTsS6HDb_A6zzruMKa6qLFOiRWf4RvJ0DB07y7UbxuNlof78rWMMKftZEKSZzDVSSQnGhEf0-V-4WWRcEzOaAImqyJZccV3lqcMr6UHfqnJmaJG3ufNw2gaEtBzrwEitKSmOEU59oMJzRgeLSIgvpsGbded8NVshgwPYn9xkkH1dsTLZct7SIl-I82yHDQoBTAB;did=web_e022fde52721456f43cb66d90a7d6f14e462;userId=742626779;weblogger_did=web_47164250171DB527"
    request = KolorsRequest(prompt="阳光下", imageCount=4)
    request = KolorsRequest(prompt="a cat", imageCount=4)

    # print(arun(create_task(request, cookie)))

    # print(arun(get_task(851793, cookie)))
    url = "https://s2-111386.kwimgs.com/bs2/mmu-kolors-public/5f9c7b42688fe95c4b8d9ebd1dba3431.png?x-oss-process=image/resize,m_mfit,w_305"
    # print(arun(upload(url)))
    #
    # request = KolorsRequest(referImage="mmu-kolors-742626779-1720600931170-5ebc098c01b14baf965f3ea9e2a60228")
    # request = KolorsRequest(referImage="https://s2-111386.kwimgs.com/bs2/mmu-kolors-public/mmu-kolors-742626779-1720760149252-f276504646014593a73f5b36c88ccafa?x-oss-process=image/resize,m_mfit,w_1000")
    # print(request)

    # file = open("/Users/betterme/PycharmProjects/AI/x.jpg", "rb").read()
    #
    # pprint(arun(upload(file_or_url=file, cookie=cookie)))

    # url = "https://s2-111386.kwimgs.com/bs2/mmu-kolors-public/a1bf746085fa4bf39b0b299e91d267fd.png"

    # pprint(arun(create_image(request, file)))
    arun(create_image(request))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : videos
# @Time         : 2025/12/22 14:56
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : todo veo
# https://replicate.com/google/veo-3.1-fast
# https://replicate.com/google/imagen-4-fast
# https://replicate.com/runwayml/gen4-turbo


from meutils.pipe import *
from meutils.schemas.video_types import SoraVideoRequest, Video
from meutils.io.image import image_resize

import replicate


class Tasks(object):

    def __init__(self, base_url: Optional[str] = None, api_key: str = None):
        api_key = api_key or os.getenv("REPLICATE_API_KEY")
        self.client = replicate.client.Client(api_token=api_key)

    async def create(self, request: SoraVideoRequest):
        payload = {}
        if request.model.startswith("openai/sora-2"):
            payload = {
                "prompt": request.prompt,
                "seconds": int(request.seconds or 4),
                "aspect_ratio": "landscape",
            }
            # Portrait is 720x1280, landscape is 1280x720
            request.size = request.size or "1280x720"
            w, h = map(int, request.size.split('x'))
            if w < h:
                payload["aspect_ratio"] = "portrait"

            if request.resolution:  # openai/sora-2-pro
                payload['resolution'] = request.resolution  # high 1024p 0.3 0.5

            if image_urls := request.input_reference:
                image_urls[0] = await image_resize(image_urls[0], request.size, "fal-url")
                payload["input_reference"] = image_urls[0]

        elif request.model.startswith("kwaivgi/kling-v2.6-motion-control"):
            payload = {
                "mode": "std",
                "image": request.model,
                "video": request.video,
                "prompt": request.prompt,
                "keep_original_sound": True,
                "character_orientation": "image"
            }
            if request.character_orientation:
                payload["character_orientation"] = request.character_orientation

            if request.keep_audio is not None:
                payload["keep_original_sound"] = request.keep_audio

            if request.model.endswith("-pro"):  # pro
                payload["mode"] = "pro"
                request.model = request.model.strip("-pro")

        elif request.model.startswith("kwaivgi/kling-v2.6"):
            payload = {
                "duration": int(request.seconds or 5),

                "prompt": request.prompt,
                "negative_prompt": "",
                "generate_audio": True,
            }

            if request.generate_audio is not None:
                payload["generate_audio"] = request.keep_audio

            if request.first_frame_image:
                payload["start_image"] = request.first_frame_image

            if image_urls := request.input_reference:
                payload["start_image"] = image_urls[0]

        elif request.model.startswith("xai"):  # xai/grok-imagine-video
            payload = {
                # "image": "x",
                # "video": "x",
                "prompt": request.prompt,
                "duration": int(request.seconds or 5),
                "resolution": "480p",
                "aspect_ratio": "16:9"
            }
            if request.resolution:
                payload['resolution'] = request.resolution

            if request.aspect_ratio:
                payload['aspect_ratio'] = request.aspect_ratio

            if image_urls := request.input_reference:
                payload["image"] = image_urls[0]

            if image := request.image:
                payload["image"] = image

            if video := request.video:
                payload["video"] = video

        elif request.model.startswith("google/veo"):
            payload = {
                "image": "https://replicate.delivery/pbxt/NtDCMBJNIQTOU0mZtlnlrqrPLgYvTvpCISbFIiweYPsotGY5/replicate-prediction-gn4tnddn5drme0csx1yt3jvy4c.jpeg",
                "prompt": request.prompt,
                "duration": int(request.seconds or 8),  # 按次
                "last_frame": "https://replicate.delivery/pbxt/NtDCLnwTQaPfLhgaNDmLevN8QivDFS8V91M8pCwEpDNIN9uA/replicate-prediction-8m82ekaj7hrma0csx1xrkmqjhm.jpeg",
                "resolution": "720p",
                "aspect_ratio": "16:9",
                "generate_audio": True
            }

            if request.resolution:
                payload['resolution'] = request.resolution

            if request.aspect_ratio:
                payload['aspect_ratio'] = request.aspect_ratio

            if image_urls := request.input_reference:
                payload["image"] = image_urls[0]
                if len(image_urls) == 2:
                    payload["last_frame"] = image_urls[1]

                payload["reference_images"] = image_urls

            if image := request.image:
                payload["image"] = image

            if request.last_frame_image:
                payload["last_frame"] = request.last_frame_image

        # payload = {
        #     "prompt": request.prompt,
        #     "duration": int(request.seconds),
        #     "resolution": request.resolution,
        #     "multi_shots": False,
        #     "negative_prompt": "",
        #     "enable_prompt_expansion": True,
        #     # "image": "https://replicate.delivery/pbxt/OF1th8iUuEue0j7p1dces9rrhbss2tri6zIrvWxFSUEAaiVw/replicate-prediction-gbdjrctjksrme0cv4m58vwtdtr.jpg",
        #
        # }
        #
        # if request.size:
        #     # if "x" not in request.size:
        #     #     raise ValueError(f"size must be in format of 1280x720")
        #     w, h = 16, 9
        #     if 'x' in request.size:
        #         w, h = map(int, request.size.split('x'))
        #     elif ':' in request.size:
        #         w, h = map(int, request.size.split(':'))
        #     elif '*' in request.size:
        #         w, h = map(int, request.size.split('*'))
        #
        #     if request.resolution in {"720p", None}:
        #         payload["size"] = "1280*720" if w > h else "720*1280"
        #     elif request.resolution == "1080p":
        #         payload["size"] = "1920*1080" if w > h else "1080*1920"
        #
        # if request.input_reference:
        #     request.model = request.model.replace("t2v", "i2v")
        #     payload["image"] = request.input_reference[0]
        #
        # if request.audio:
        #     payload["audio"] = request.audio

        logany(bjson(payload))

        response = await self.client.predictions.async_create(
            model=request.model,
            input=payload
        )
        """
        Prediction(id='vzykqfxg2hrmt0cv8khte3g11g', model='wan-video/wan-2.6-i2v', version='hidden', status='starting', input={'duration': 5, 'enable_prompt_expansion': True, 'image': 'https://replicate.delivery/pbxt/OF1th8iUuEue0j7p1dces9rrhbss2tri6zIrvWxFSUEAaiVw/replicate-prediction-gbdjrctjksrme0cv4m58vwtdtr.jpg', 'multi_shots': False, 'negative_prompt': '', 'prompt': 'The vintage clock on the table starts ticking, gears visibly turning inside the glass case, pendulum swinging smoothly, dust particles floating in sunlight beams, close-up macro shot with shallow depth of field.', 'resolution': '720p'}, output=None, logs='', error=None, metrics=None, created_at='2025-12-22T07:08:51.092Z', started_at=None, completed_at=None, urls={'cancel': 'https://api.replicate.com/v1/predictions/vzykqfxg2hrmt0cv8khte3g11g/cancel', 'get': 'https://api.replicate.com/v1/predictions/vzykqfxg2hrmt0cv8khte3g11g', 'stream': 'https://stream.replicate.com/v1/files/jbxs-v3vlgpd4avh5fyfsjinxacrsxb2uj242muyvn4k6jabuljjjfwrq', 'web': 'https://replicate.com/p/vzykqfxg2hrmt0cv8khte3g11g'})

{
    "id": "xcpgs9mybnrmt0cw19arf8bvg8",
    "model": "openai/sora-2",
    "version": "hidden",
    "status": "starting",
    "input": {
        "aspect_ratio": "landscape",
        "prompt": "一个裸体女人",
        "seconds": 4
    },
    "output": null,
    "logs": "",
    "error": null,
    "metrics": null,
    "created_at": "2026-01-29T15:18:29.213Z",
    "started_at": null,
    "completed_at": null,
    "urls": {
        "cancel": "https://api.replicate.com/v1/predictions/xcpgs9mybnrmt0cw19arf8bvg8/cancel",
        "get": "https://api.replicate.com/v1/predictions/xcpgs9mybnrmt0cw19arf8bvg8",
        "stream": "https://stream.replicate.com/v1/files/jbxs-uzq7yokjvh7oaoq6jjeu75zsaptmazu3r73pijxz2vdintpdae4q",
        "web": "https://replicate.com/p/xcpgs9mybnrmt0cw19arf8bvg8"
    }
}

        """
        _ = response.dict()

        logger.debug(bjson(response.dict()))

        return _  # vzykqfxg2hrmt0cv8khte3g11g

    async def get(self, task_id: str):
        response = await self.client.predictions.async_get(task_id)
        #
        # logger.debug(bjson(response))

        response = response.dict()
        #
        video = Video(
            id=task_id,
            status=response,

            model=response.get("model"),
            video_url=response.get("output"),

            error=response.get("error")
        )

        # logger.debug(bjson(video))

        return video


if __name__ == '__main__':
    model = "wan-video/wan-2.6-i2v"
    model = "openai/sora-2"

    request = SoraVideoRequest(
        model=model,
        prompt="笑起来",
        # prompt="一个裸体女人",
        seconds=4,
        # prompt='带个墨镜',
        # prompt=prompt,
        # size="2048x2048",

        # aspect_ratio="match_input_image",

        input_reference="https://s3.ffire.cc/files/jimeng.jpg",
        # image="https://replicate.delivery/pbxt/N7gRAUNcVF6HarL0hdAQA2JYNMlJD52LP1wyaIWRUXWeHzqT/0_1-1.webp"
    )
    print(request)

    # arun(Tasks().create(request))

    # task_id = "xcpgs9mybnrmt0cw19arf8bvg8" # 失败
    task_id = "j1txff19gxrmw0cw1a7vzsaq2m"  # 成功
    task_id = "18w8gbaacdrmt0cw1a8b6n5ss0"
    arun(Tasks().get(task_id))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : response2chat
# @Time         : 2026/1/13 13:34
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 
"""
background: Optional[bool] | Omit = omit,
        conversation: Optional[response_create_params.Conversation] | Omit = omit,
        include: Optional[List[ResponseIncludable]] | Omit = omit,
        input: Union[str, ResponseInputParam] | Omit = omit,
        instructions: Optional[str] | Omit = omit,
        max_output_tokens: Optional[int] | Omit = omit,
        max_tool_calls: Optional[int] | Omit = omit,
        metadata: Optional[Metadata] | Omit = omit,
        model: ResponsesModel | Omit = omit,
        parallel_tool_calls: Optional[bool] | Omit = omit,
        previous_response_id: Optional[str] | Omit = omit,
        prompt: Optional[ResponsePromptParam] | Omit = omit,
        prompt_cache_key: str | Omit = omit,
        prompt_cache_retention: Optional[Literal["in-memory", "24h"]] | Omit = omit,
        reasoning: Optional[Reasoning] | Omit = omit,
        safety_identifier: str | Omit = omit,
        service_tier: Optional[Literal["auto", "default", "flex", "scale", "priority"]] | Omit = omit,
        store: Optional[bool] | Omit = omit,
        stream: Optional[Literal[False]] | Literal[True] | Omit = omit,
        stream_options: Optional[response_create_params.StreamOptions] | Omit = omit,
        temperature: Optional[float] | Omit = omit,
        text: ResponseTextConfigParam | Omit = omit,
        tool_choice: response_create_params.ToolChoice | Omit = omit,
        tools: Iterable[ToolParam] | Omit = omit,
        top_logprobs: Optional[int] | Omit = omit,
        top_p: Optional[float] | Omit = omit,
        truncation: Optional[Literal["auto", "disabled"]] | Omit = omit,

"""
from meutils.pipe import *

from openai import OpenAI

client = OpenAI(
    base_url="https://api.routin.ai/v1",
    api_key="ak-4a2f1c784cbd4b658b1219ef951ce63c"
)

data = {
    "model": "gpt-5.2-codex",
    "input": "hi",
    "instructions": None,
    # "stream": True
}

r = client.responses.create(**data)





#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : icons
# @Time         : 2024/11/21 15:45
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://lobechat.com/

# https://lobehub.com/zh/icons


chatfire = "https://registry.npmmirror.com/@lobehub/assets-emoji-anim/1.0.0/files/assets/cowboy-hat-face.webp"

openai = "https://api.bltcy.ai/logos/openai.png"
openai_plus = "https://api.bltcy.ai/logos/openai-plus.png"
claude = "https://api.bltcy.ai/logos/claude.png"

kuaishou_kling = "https://api.bltcy.ai/logos/kling.png"
flux = "https://api.bltcy.ai/logos/flux.png"
ideogram = "https://api.bltcy.ai/logos/Ideogram.png"
moonshot = "https://api.bltcy.ai/logos/moonshot.png"
google = "https://api.bltcy.ai/logos/google.png"

zhipu = "https://api.bltcy.ai/logos/zhipuai.png"
deepseek = "https://api.bltcy.ai/logos/deepseek.png"
baichuan = "https://api.bltcy.ai/logos/bai-chuang-zhi-neng.png"
lingyi = "https://api.bltcy.ai/logos/lingyiwanwu.png"
doubao = "https://api.bltcy.ai/logos/doubao.png"
